@@ -1,6 +1,7 @@
 import sys
 import typing
-import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
 class Device:
@@ -39,18 +40,18 @@ class Device:
 
     @classmethod
     def lock(cls):
-        ''' Locks the device so that it's guaranteed, that no samples are read from the streams until :meth: unlock is called. This is useful if you want to do start/stop/pause/resume some sounds at the same time.
+        ''' Locks the device so that it's guaranteed, that no samples are read from the streams until :meth:`unlock` is called. This is useful if you want to do start/stop/pause/resume some sounds at the same time.
 
         '''
         pass
 
     @classmethod
-    def play(cls, sound: 'bpy.types.Sound', keep: bool = False) -> 'Handle':
+    def play(cls, sound: 'Sound', keep: bool = False) -> 'Handle':
         ''' Plays a sound.
 
         :param sound: The sound to play.
-        :type sound: 'bpy.types.Sound'
-        :param keep: Handle.keep .
+        :type sound: 'Sound'
+        :param keep: `Handle.keep`.
         :type keep: bool
         :rtype: 'Handle'
         :return: The playback handle with which playback can be controlled with.
@@ -66,7 +67,7 @@ class Device:
 
     @classmethod
     def unlock(cls):
-        ''' Unlocks the device after a lock call, see :meth: lock for details.
+        ''' Unlocks the device after a lock call, see :meth:`lock` for details.
 
         '''
         pass
@@ -92,19 +93,18 @@ class DynamicMusic:
     ''' The volume of the scene.'''
 
     @classmethod
-    def addScene(cls, scene: 'bpy.types.Sound') -> int:
+    def addScene(cls, scene: 'Sound') -> int:
         ''' Adds a new scene.
 
         :param scene: The scene sound.
-        :type scene: 'bpy.types.Sound'
+        :type scene: 'Sound'
         :rtype: int
         :return: The new scene id.
         '''
         pass
 
     @classmethod
-    def addTransition(cls, ini: int, end: int,
-                      transition: 'bpy.types.Sound') -> bool:
+    def addTransition(cls, ini: int, end: int, transition: 'Sound') -> bool:
         ''' Adds a new scene.
 
         :param ini: the initial scene foor the transition.
@@ -112,7 +112,7 @@ class DynamicMusic:
         :param end: The final scene for the transition.
         :type end: int
         :param transition: The transition sound.
-        :type transition: 'bpy.types.Sound'
+        :type transition: 'Sound'
         :rtype: bool
         :return: false if the ini or end scenes don't exist, true othrwise.
         '''
@@ -154,7 +154,7 @@ class Handle:
     ''' This factor is used for distance based attenuation of the source.'''
 
     cone_angle_inner = None
-    ''' The opening angle of the inner cone of the source. If the cone values of a source are set there are two (audible) cones with the apex at the :attr: location of the source and with infinite height, heading in the direction of the source's :attr: orientation . In the inner cone the volume is normal. Outside the outer cone the volume will be :attr: cone_volume_outer and in the area between the volume will be interpolated linearly.'''
+    ''' The opening angle of the inner cone of the source. If the cone values of a source are set there are two (audible) cones with the apex at the :attr:`location` of the source and with infinite height, heading in the direction of the source's :attr:`orientation`. In the inner cone the volume is normal. Outside the outer cone the volume will be :attr:`cone_volume_outer` and in the area between the volume will be interpolated linearly.'''
 
     cone_angle_outer = None
     ''' The opening angle of the outer cone of the source.'''
@@ -166,7 +166,7 @@ class Handle:
     ''' The maximum distance of the source. If the listener is further away the source volume will be 0.'''
 
     distance_reference = None
-    ''' The reference distance of the source. At this distance the volume will be exactly :attr: volume .'''
+    ''' The reference distance of the source. At this distance the volume will be exactly :attr:`volume`.'''
 
     keep = None
     ''' Whether the sound should be kept paused in the device when its end is reached. This can be used to seek the sound to some position and start playback again.'''
@@ -277,11 +277,11 @@ class PlaybackManager:
         pass
 
     @classmethod
-    def play(cls, sound: 'bpy.types.Sound', catKey: int) -> 'Handle':
+    def play(cls, sound: 'Sound', catKey: int) -> 'Handle':
         ''' Plays a sound through the playback manager and assigns it to a category.
 
         :param sound: The sound to play.
-        :type sound: 'bpy.types.Sound'
+        :type sound: 'Sound'
         :param catKey: the key of the category in which the sound will be added, if it doesn't exist, a new one will be created.
         :type catKey: int
         :rtype: 'Handle'
@@ -355,13 +355,13 @@ class Sequence:
         ''' Adds a new entry to the sequence.
 
         :param sound: The sound this entry should play.
-        :type sound: 'bpy.types.Sound'
+        :type sound: 'Sound'
         :param begin: The start time.
-        :type begin: 
+        :type begin: float
         :param end: The end time or a negative value if determined by the sound.
-        :type end: 
+        :type end: float
         :param skip: How much seconds should be skipped at the beginning.
-        :type skip: 
+        :type skip: float
         :rtype: 'SequenceEntry'
         :return: The entry added.
         '''
@@ -400,7 +400,7 @@ class SequenceEntry:
     ''' This factor is used for distance based attenuation of the source.'''
 
     cone_angle_inner = None
-    ''' The opening angle of the inner cone of the source. If the cone values of a source are set there are two (audible) cones with the apex at the :attr: location of the source and with infinite height, heading in the direction of the source's :attr: orientation . In the inner cone the volume is normal. Outside the outer cone the volume will be :attr: cone_volume_outer and in the area between the volume will be interpolated linearly.'''
+    ''' The opening angle of the inner cone of the source. If the cone values of a source are set there are two (audible) cones with the apex at the :attr:`location` of the source and with infinite height, heading in the direction of the source's :attr:`orientation`. In the inner cone the volume is normal. Outside the outer cone the volume will be :attr:`cone_volume_outer` and in the area between the volume will be interpolated linearly.'''
 
     cone_angle_outer = None
     ''' The opening angle of the outer cone of the source.'''
@@ -412,7 +412,7 @@ class SequenceEntry:
     ''' The maximum distance of the source. If the listener is further away the source volume will be 0.'''
 
     distance_reference = None
-    ''' The reference distance of the source. At this distance the volume will be exactly :attr: volume .'''
+    ''' The reference distance of the source. At this distance the volume will be exactly :attr:`volume`.'''
 
     muted = None
     ''' Whether the entry is muted.'''
@@ -434,11 +434,11 @@ class SequenceEntry:
         ''' Moves the entry.
 
         :param begin: The new start time.
-        :type begin: 
+        :type begin: float
         :param end: The new end time or a negative value if unknown.
-        :type end: 
+        :type end: float
         :param skip: How many seconds to skip at the beginning.
-        :type skip: 
+        :type skip: float
         '''
         pass
 
@@ -469,108 +469,106 @@ class Sound:
     ''' The sample specification of the sound as a tuple with rate and channel count.'''
 
     @classmethod
-    def buffer(cls, data, rate) -> 'bpy.types.Sound':
+    def buffer(cls, data: typing.Any, rate: float) -> 'Sound':
         ''' Creates a sound from a data buffer.
 
         :param data: The data as two dimensional numpy array.
-        :type data: 
+        :type data: typing.Any
         :param rate: The sample rate.
-        :type rate: 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :type rate: float
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def file(cls, filename: str) -> 'bpy.types.Sound':
+    def file(cls, filename: str) -> 'Sound':
         ''' Creates a sound object of a sound file.
 
         :param filename: Path of the file.
         :type filename: str
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def list(cls) -> 'bpy.types.Sound':
+    def list(cls) -> 'Sound':
         ''' Creates an empty sound list that can contain several sounds.
 
         :param random: whether the playback will be random or not.
         :type random: int
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def sawtooth(cls, frequency: float,
-                 rate: int = 48000) -> 'bpy.types.Sound':
+    def sawtooth(cls, frequency: float, rate: int = 48000) -> 'Sound':
         ''' Creates a sawtooth sound which plays a sawtooth wave.
 
         :param frequency: The frequency of the sawtooth wave in Hz.
         :type frequency: float
         :param rate: The sampling rate in Hz. It's recommended to set this value to the playback device's samling rate to avoid resamping.
         :type rate: int
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def silence(cls, rate: int = 48000) -> 'bpy.types.Sound':
+    def silence(cls, rate: int = 48000) -> 'Sound':
         ''' Creates a silence sound which plays simple silence.
 
         :param rate: The sampling rate in Hz. It's recommended to set this value to the playback device's samling rate to avoid resamping.
         :type rate: int
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def sine(cls, frequency: float, rate: int = 48000) -> 'bpy.types.Sound':
+    def sine(cls, frequency: float, rate: int = 48000) -> 'Sound':
         ''' Creates a sine sound which plays a sine wave.
 
         :param frequency: The frequency of the sine wave in Hz.
         :type frequency: float
         :param rate: The sampling rate in Hz. It's recommended to set this value to the playback device's samling rate to avoid resamping.
         :type rate: int
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def square(cls, frequency: float, rate: int = 48000) -> 'bpy.types.Sound':
+    def square(cls, frequency: float, rate: int = 48000) -> 'Sound':
         ''' Creates a square sound which plays a square wave.
 
         :param frequency: The frequency of the square wave in Hz.
         :type frequency: float
         :param rate: The sampling rate in Hz. It's recommended to set this value to the playback device's samling rate to avoid resamping.
         :type rate: int
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def triangle(cls, frequency: float,
-                 rate: int = 48000) -> 'bpy.types.Sound':
+    def triangle(cls, frequency: float, rate: int = 48000) -> 'Sound':
         ''' Creates a triangle sound which plays a triangle wave.
 
         :param frequency: The frequency of the triangle wave in Hz.
         :type frequency: float
         :param rate: The sampling rate in Hz. It's recommended to set this value to the playback device's samling rate to avoid resamping.
         :type rate: int
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
     def ADSR(cls, attack: float, decay: float, sustain: float,
-             release: float) -> 'bpy.types.Sound':
+             release: float) -> 'Sound':
         ''' Attack-Decay-Sustain-Release envelopes the volume of a sound. Note: there is currently no way to trigger the release with this API.
 
         :param attack: The attack time in seconds.
@@ -581,64 +579,65 @@ class Sound:
         :type sustain: float
         :param release: The release level.
         :type release: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def accumulate(cls, additive=False) -> 'bpy.types.Sound':
+    def accumulate(cls, additive: typing.Any = False) -> 'Sound':
         ''' Accumulates a sound by summing over positive input differences thus generating a monotonic sigal. If additivity is set to true negative input differences get added too, but positive ones with a factor of two. Note that with additivity the signal is not monotonic anymore.
 
         :param time: 
         :type time: bool
-        :param additive: 
-        :type additive: 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :param additive:  Whether the accumulation should be additive or not.
+        :type additive: typing.Any
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def addSound(cls, sound: 'bpy.types.Sound'):
+    def addSound(cls, sound: 'Sound'):
         ''' Adds a new sound to a sound list.
 
         :param sound: The sound that will be added to the list.
-        :type sound: 'bpy.types.Sound'
+        :type sound: 'Sound'
         '''
         pass
 
     @classmethod
-    def cache(cls) -> 'bpy.types.Sound':
+    def cache(cls) -> 'Sound':
         ''' Caches a sound into RAM. This saves CPU usage needed for decoding and file access if the underlying sound reads from a file on the harddisk, but it consumes a lot of memory.
 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def data(cls):
+    def data(cls) -> typing.Any:
         ''' Retrieves the data of the sound as numpy array.
 
+        :rtype: typing.Any
         :return: A two dimensional numpy float array.
         '''
         pass
 
     @classmethod
-    def delay(cls, time: float) -> 'bpy.types.Sound':
+    def delay(cls, time: float) -> 'Sound':
         ''' Delays by playing adding silence in front of the other sound's data.
 
         :param time: How many seconds of silence should be added before the sound.
         :type time: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
     def envelope(cls, attack: float, release: float, threshold: float,
-                 arthreshold: float) -> 'bpy.types.Sound':
+                 arthreshold: float) -> 'Sound':
         ''' Delays by playing adding silence in front of the other sound's data.
 
         :param attack: The attack factor.
@@ -649,223 +648,223 @@ class Sound:
         :type threshold: float
         :param arthreshold: The attack/release threshold value.
         :type arthreshold: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def fadein(cls, start: float, length: float) -> 'bpy.types.Sound':
+    def fadein(cls, start: float, length: float) -> 'Sound':
         ''' Fades a sound in by raising the volume linearly in the given time interval.
 
         :param start: Time in seconds when the fading should start.
         :type start: float
         :param length: Time in seconds how long the fading should last.
         :type length: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def fadeout(cls, start: float, length: float) -> 'bpy.types.Sound':
+    def fadeout(cls, start: float, length: float) -> 'Sound':
         ''' Fades a sound in by lowering the volume linearly in the given time interval.
 
         :param start: Time in seconds when the fading should start.
         :type start: float
         :param length: Time in seconds how long the fading should last.
         :type length: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def filter(cls, b: typing.List[float], a=(1)) -> 'bpy.types.Sound':
+    def filter(cls, b: typing.List[float], a=(1)) -> 'Sound':
         ''' Filters a sound with the supplied IIR filter coefficients. Without the second parameter you'll get a FIR filter. If the first value of the a sequence is 0, it will be set to 1 automatically. If the first value of the a sequence is neither 0 nor 1, all filter coefficients will be scaled by this value so that it is 1 in the end, you don't have to scale yourself.
 
         :param b: The nominator filter coefficients.
         :type b: typing.List[float]
         :param a: The denominator filter coefficients.
         :type a: typing.List[float]
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def highpass(cls, frequency: float, Q: float = 0.5) -> 'bpy.types.Sound':
-        ''' Creates a second order highpass filter based on the transfer function :math: H(s) = s^2 / (s^2 + s/Q + 1)
+    def highpass(cls, frequency: float, Q: float = 0.5) -> 'Sound':
+        ''' Creates a second order highpass filter based on the transfer function :math:`H(s) = s^2 / (s^2 + s/Q + 1)`
 
         :param frequency: The cut off trequency of the highpass.
         :type frequency: float
         :param Q: Q factor of the lowpass.
         :type Q: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def join(cls, sound: 'bpy.types.Sound') -> 'bpy.types.Sound':
+    def join(cls, sound: 'Sound') -> 'Sound':
         ''' Plays two factories in sequence.
 
         :param sound: The sound to play second.
-        :type sound: 'bpy.types.Sound'
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :type sound: 'Sound'
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def limit(cls, start: float, end: float) -> 'bpy.types.Sound':
+    def limit(cls, start: float, end: float) -> 'Sound':
         ''' Limits a sound within a specific start and end time.
 
         :param start: Start time in seconds.
         :type start: float
         :param end: End time in seconds.
         :type end: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def loop(cls, count) -> 'bpy.types.Sound':
+    def loop(cls, count: typing.Any) -> 'Sound':
         ''' Loops a sound.
 
         :param count: How often the sound should be looped. Negative values mean endlessly.
-        :type count: 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :type count: typing.Any
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def lowpass(cls, frequency: float, Q: float = 0.5) -> 'bpy.types.Sound':
-        ''' Creates a second order lowpass filter based on the transfer function :math: H(s) = 1 / (s^2 + s/Q + 1)
+    def lowpass(cls, frequency: float, Q: float = 0.5) -> 'Sound':
+        ''' Creates a second order lowpass filter based on the transfer function :math:`H(s) = 1 / (s^2 + s/Q + 1)`
 
         :param frequency: The cut off trequency of the lowpass.
         :type frequency: float
         :param Q: Q factor of the lowpass.
         :type Q: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def mix(cls, sound: 'bpy.types.Sound') -> 'bpy.types.Sound':
+    def mix(cls, sound: 'Sound') -> 'Sound':
         ''' Mixes two factories.
 
         :param sound: The sound to mix over the other.
-        :type sound: 'bpy.types.Sound'
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :type sound: 'Sound'
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def modulate(cls, sound: 'bpy.types.Sound') -> 'bpy.types.Sound':
+    def modulate(cls, sound: 'Sound') -> 'Sound':
         ''' Modulates two factories.
 
         :param sound: The sound to modulate over the other.
-        :type sound: 'bpy.types.Sound'
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :type sound: 'Sound'
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def mutable(cls) -> 'bpy.types.Sound':
+    def mutable(cls) -> 'Sound':
         ''' Creates a sound that will be restarted when sought backwards. If the original sound is a sound list, the playing sound can change.
 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def pingpong(cls) -> 'bpy.types.Sound':
+    def pingpong(cls) -> 'Sound':
         ''' Plays a sound forward and then backward. This is like joining a sound with its reverse.
 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def pitch(cls, factor: float) -> 'bpy.types.Sound':
+    def pitch(cls, factor: float) -> 'Sound':
         ''' Changes the pitch of a sound with a specific factor.
 
         :param factor: The factor to change the pitch with.
         :type factor: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def rechannel(cls, channels: int) -> 'bpy.types.Sound':
+    def rechannel(cls, channels: int) -> 'Sound':
         ''' Rechannels the sound.
 
         :param channels: The new channel configuration.
         :type channels: int
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def resample(cls, rate, high_quality: bool) -> 'bpy.types.Sound':
+    def resample(cls, rate: float, high_quality: bool) -> 'Sound':
         ''' Resamples the sound.
 
         :param rate: The new sample rate.
-        :type rate: 
+        :type rate: float
         :param high_quality: When true use a higher quality but slower resampler.
         :type high_quality: bool
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def reverse(cls) -> 'bpy.types.Sound':
+    def reverse(cls) -> 'Sound':
         ''' Plays a sound reversed.
 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def sum(cls) -> 'bpy.types.Sound':
+    def sum(cls) -> 'Sound':
         ''' Sums the samples of a sound.
 
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def threshold(cls, threshold=' 0') -> 'bpy.types.Sound':
+    def threshold(cls, threshold=' 0') -> 'Sound':
         ''' Makes a threshold wave out of an audio wave by setting all samples with a amplitude >= threshold to 1, all <= -threshold to -1 and all between to 0.
 
         :param threshold: Threshold value over which an amplitude counts non-zero.
         :type threshold: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
     @classmethod
-    def volume(cls, volume: float) -> 'bpy.types.Sound':
+    def volume(cls, volume: float) -> 'Sound':
         ''' Changes the volume of a sound.
 
         :param volume: The new volume..
         :type volume: float
-        :rtype: 'bpy.types.Sound'
-        :return: Sound object.
+        :rtype: 'Sound'
+        :return: `Sound` object.
         '''
         pass
 
