@@ -1,6 +1,7 @@
 import sys
 import typing
 import bpy_types
+import rna_prop_ui
 import bl_ui.properties_grease_pencil_common
 
 GenericType = typing.TypeVar("GenericType")
@@ -3058,6 +3059,216 @@ class DOPESHEET_MT_view_pie(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
+class DOPESHEET_PT_custom_props_action(rna_prop_ui.PropertyPanel,
+                                       bpy_types.Panel, bpy_types._GenericUI):
+    bl_category = None
+    ''' '''
+
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_order = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
 class DopesheetActionPanelBase:
     bl_label = None
     ''' '''
