@@ -2,6 +2,8 @@ import sys
 import typing
 import bmesh.types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def edge_rotate(edge: 'bmesh.types.BMEdge',
                 ccw: bool = False) -> 'bmesh.types.BMEdge':
@@ -19,7 +21,7 @@ def edge_rotate(edge: 'bmesh.types.BMEdge',
 
 
 def edge_split(edge: 'bmesh.types.BMEdge', vert: 'bmesh.types.BMVert',
-               fac: float) -> tuple:
+               fac: float) -> typing.Tuple:
     ''' Split an edge, return the newly created data.
 
     :param edge: The edge to split.
@@ -28,7 +30,7 @@ def edge_split(edge: 'bmesh.types.BMEdge', vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param fac: The point on the edge where the new vert will be created [0 - 1].
     :type fac: float
-    :rtype: tuple
+    :rtype: typing.Tuple
     :return: The newly created (edge, vert) pair.
     '''
 
@@ -65,7 +67,8 @@ def face_split(face: 'bmesh.types.BMFace',
                vert_b: 'bmesh.types.BMVert',
                coords: typing.List[float] = (),
                use_exist: bool = True,
-               example: 'bmesh.types.BMEdge' = None) -> 'bmesh.types.BMLoop':
+               example: 'bmesh.types.BMEdge' = None
+               ) -> typing.Tuple['bmesh.types.BMFace', 'bmesh.types.BMLoop']:
     ''' Face split with optional intermediate points.
 
     :param face: The face to cut.
@@ -80,7 +83,7 @@ def face_split(face: 'bmesh.types.BMFace',
     :type use_exist: bool
     :param example: Newly created edge will copy settings from this one.
     :type example: 'bmesh.types.BMEdge'
-    :rtype: 'bmesh.types.BMLoop'
+    :rtype: typing.Tuple['bmesh.types.BMFace', 'bmesh.types.BMLoop']
     :return: The newly created face or None on failure.
     '''
 
@@ -88,7 +91,7 @@ def face_split(face: 'bmesh.types.BMFace',
 
 
 def face_split_edgenet(face: 'bmesh.types.BMFace',
-                       edgenet: 'bmesh.types.BMEdge') -> 'bmesh.types.BMFace':
+                       edgenet: 'bmesh.types.BMEdge') -> typing.Tuple:
     ''' Splits a face into any number of regions defined by an edgenet.
 
     :param face: The face to split. The face to split.
@@ -97,7 +100,7 @@ def face_split_edgenet(face: 'bmesh.types.BMFace',
     :type face: 'bmesh.types.BMFace'
     :param edgenet: Sequence of edges.
     :type edgenet: 'bmesh.types.BMEdge'
-    :rtype: 'bmesh.types.BMFace'
+    :rtype: typing.Tuple
     :return: The newly created faces.
     '''
 
@@ -178,14 +181,14 @@ def vert_dissolve(vert: 'bmesh.types.BMVert') -> bool:
 
 
 def vert_separate(vert: 'bmesh.types.BMVert',
-                  edges: 'bmesh.types.BMEdge') -> 'bmesh.types.BMVert':
+                  edges: 'bmesh.types.BMEdge') -> typing.Tuple:
     ''' Separate this vertex at every edge.
 
     :param vert: The vert to be separated.
     :type vert: 'bmesh.types.BMVert'
     :param edges: The edges to separated.
     :type edges: 'bmesh.types.BMEdge'
-    :rtype: 'bmesh.types.BMVert'
+    :rtype: typing.Tuple
     :return: The newly separated verts (including the vertex passed).
     '''
 
