@@ -1,18 +1,19 @@
 import sys
 import typing
-from . import handlers
-from . import translations
-from . import timers
 from . import icons
+from . import translations
+from . import handlers
+from . import timers
 
 GenericType = typing.TypeVar("GenericType")
 
 
-def is_job_running(job_type: str):
+def is_job_running(job_type: typing.Optional[str]) -> typing.Any:
     ''' Check whether a job of the given type is running.
 
-    :param job_type: rna_enum_wm_job_type_items .
-    :type job_type: str
+    :param job_type: `rna_enum_wm_job_type_items`.
+    :type job_type: typing.Optional[str]
+    :rtype: typing.Any
     :return: Whether a job of the given type is currently running.
     '''
 
@@ -24,15 +25,15 @@ alembic = None
 '''
 
 autoexec_fail = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 autoexec_fail_message = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 autoexec_fail_quiet = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 background = None
@@ -40,7 +41,7 @@ background = None
 '''
 
 binary_path = None
-''' The location of Blender's executable, useful for utilities that open new instances
+''' The location of Blender's executable, useful for utilities that open new instances. Read-only unless Blender is built as a Python module - in this case the value is an empty string which script authors may point to a Blender binary.
 '''
 
 build_branch = None
@@ -80,7 +81,7 @@ build_linkflags = None
 '''
 
 build_options = None
-''' Constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, coreaudio=False, jack=True, pulseaudio=True, wasapi=False, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, io_wavefront_obj=True, io_stl=True, io_gpencil=True, opencolorio=True, openmp=False, openvdb=True, alembic=True, usd=True, fluid=True, xr_openxr=True, potrace=True, pugixml=True, haru=True)
+''' Constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor_cpu=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, coreaudio=False, jack=True, pulseaudio=True, wasapi=False, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, io_wavefront_obj=True, io_stl=True, io_gpencil=True, opencolorio=True, openmp=True, openvdb=True, alembic=True, usd=True, fluid=True, xr_openxr=True, potrace=True, pugixml=True, haru=True)
 '''
 
 build_platform = None
@@ -172,7 +173,7 @@ factory_startup = None
 '''
 
 ffmpeg = None
-''' Constant value bpy.app.ffmpeg(supported=True, avcodec_version=(59, 18, 100), avcodec_version_string='59, 18, 100', avdevice_version=(59, 4, 100), avdevice_version_string='59, 4, 100', avformat_version=(59, 16, 100), avformat_version_string='59, 16, 100', avutil_version=(57, 17, 100), avutil_version_string='57, 17, 100', swscale_version=(6, 4, 100), swscale_version_string=' 6, 4, 100')
+''' Constant value bpy.app.ffmpeg(supported=True, avcodec_version=(59, 37, 100), avcodec_version_string='59, 37, 100', avdevice_version=(59, 7, 100), avdevice_version_string='59, 7, 100', avformat_version=(59, 27, 100), avformat_version_string='59, 27, 100', avutil_version=(57, 28, 100), avutil_version_string='57, 28, 100', swscale_version=(6, 7, 100), swscale_version_string=' 6, 7, 100')
 '''
 
 ocio = None
@@ -180,11 +181,11 @@ ocio = None
 '''
 
 oiio = None
-''' Constant value bpy.app.oiio(supported=True, version=(2, 3, 13), version_string=' 2, 3, 13')
+''' Constant value bpy.app.oiio(supported=True, version=(2, 3, 20), version_string=' 2, 3, 20')
 '''
 
 opensubdiv = None
-''' Constant value bpy.app.opensubdiv(supported=True, version=(0, 0, 0), version_string=' 0, 0, 0')
+''' Constant value bpy.app.opensubdiv(supported=True, version=(3, 4, 4), version_string=' 3, 4, 4')
 '''
 
 openvdb = None
@@ -232,7 +233,7 @@ version_cycle = None
 '''
 
 version_file = None
-''' The Blender version, as a tuple, last used to save a .blend file, compatible with bpy.data.version . This value should be used for handling compatibility changes between Blender versions
+''' The Blender version, as a tuple, last used to save a .blend file, compatible with ``bpy.data.version``. This value should be used for handling compatibility changes between Blender versions
 '''
 
 version_string = None
