@@ -9,12 +9,12 @@ GenericType = typing.TypeVar("GenericType")
 def align(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: bool = None):
+          undo: typing.Optional[bool] = None):
     ''' Align selected bones to the active bone (or to their parent)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -24,21 +24,20 @@ def armature_layers(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
+        undo: typing.Optional[bool] = None,
         *,
-        layers: typing.List[bool] = (False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False)):
+        layers: typing.Union[typing.List[bool], typing.Any] = (
+            False, False, False, False, False, False, False, False, False,
+            False, False, False, False, False, False, False, False, False,
+            False, False, False, False, False, False, False, False, False,
+            False, False, False, False, False)):
     ''' Change the visible armature layers
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param layers: Layer, Armature layers to make visible
-    :type layers: typing.List[bool]
+    :type layers: typing.Union[typing.List[bool], typing.Any]
     '''
 
     pass
@@ -47,40 +46,38 @@ def armature_layers(
 def autoside_names(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   type: typing.Union[str, int] = 'XAXIS'):
+                   type: typing.Optional[typing.Any] = 'XAXIS'):
     ''' Automatically renames the selected bones according to which side of the target axis they fall on
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param type: Axis, Axis tag names with * XAXIS X-Axis -- Left/Right. * YAXIS Y-Axis -- Front/Back. * ZAXIS Z-Axis -- Top/Bottom.
-    :type type: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param type: Axis, Axis tag names with * ``XAXIS`` X-Axis -- Left/Right. * ``YAXIS`` Y-Axis -- Front/Back. * ``ZAXIS`` Z-Axis -- Top/Bottom.
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
 
 
-def bone_layers(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        layers: typing.List[bool] = (False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False, False, False, False, False,
-                                     False, False)):
+def bone_layers(override_context: typing.
+                Union[typing.Dict, 'bpy.types.Context'] = None,
+                execution_context: typing.Union[str, int] = None,
+                undo: typing.Optional[bool] = None,
+                *,
+                layers: typing.Union[typing.List[bool], typing.Any] = (
+                    False, False, False, False, False, False, False, False,
+                    False, False, False, False, False, False, False, False,
+                    False, False, False, False, False, False, False, False,
+                    False, False, False, False, False, False, False, False)):
     ''' Change the layers that the selected bones belong to
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param layers: Layer, Armature layers that bone belongs to
-    :type layers: typing.List[bool]
+    :type layers: typing.Union[typing.List[bool], typing.Any]
     '''
 
     pass
@@ -89,16 +86,16 @@ def bone_layers(
 def bone_primitive_add(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: bool = None,
+                       undo: typing.Optional[bool] = None,
                        *,
-                       name: str = "Bone"):
+                       name: typing.Union[str, typing.Any] = "Bone"):
     ''' Add a new bone located at the 3D cursor
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param name: Name, Name of the newly created bone
-    :type name: str
+    :type name: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -107,22 +104,22 @@ def bone_primitive_add(override_context: typing.
 def calculate_roll(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   type: typing.Union[str, int] = 'POS_X',
-                   axis_flip: bool = False,
-                   axis_only: bool = False):
+                   type: typing.Optional[typing.Any] = 'POS_X',
+                   axis_flip: typing.Union[bool, typing.Any] = False,
+                   axis_only: typing.Union[bool, typing.Any] = False):
     ''' Automatically fix alignment of select bones' axes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     :param axis_flip: Flip Axis, Negate the alignment axis
-    :type axis_flip: bool
+    :type axis_flip: typing.Union[bool, typing.Any]
     :param axis_only: Shortest Rotation, Ignore the axis direction, use the shortest rotation to align
-    :type axis_only: bool
+    :type axis_only: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -131,12 +128,12 @@ def calculate_roll(override_context: typing.
 def click_extrude(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Create a new bone going from the last selected joint to the mouse position
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -145,12 +142,12 @@ def click_extrude(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Remove selected bones from the armature
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -159,12 +156,12 @@ def delete(override_context: typing.Union[typing.
 def dissolve(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Dissolve selected bones from the armature
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -173,38 +170,38 @@ def dissolve(override_context: typing.Union[typing.
 def duplicate(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
+              undo: typing.Optional[bool] = None,
               *,
-              do_flip_names: bool = False):
+              do_flip_names: typing.Union[bool, typing.Any] = False):
     ''' Make copies of the selected bones within the same armature
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param do_flip_names: Flip Names, Try to flip names of the bones, if possible, instead of adding a number extension
-    :type do_flip_names: bool
+    :type do_flip_names: typing.Union[bool, typing.Any]
     '''
 
     pass
 
 
-def duplicate_move(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        ARMATURE_OT_duplicate: 'duplicate' = None,
-        TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
+def duplicate_move(override_context: typing.
+                   Union[typing.Dict, 'bpy.types.Context'] = None,
+                   execution_context: typing.Union[str, int] = None,
+                   undo: typing.Optional[bool] = None,
+                   *,
+                   ARMATURE_OT_duplicate: typing.Optional['duplicate'] = None,
+                   TRANSFORM_OT_translate: typing.
+                   Optional['bpy.ops.transform.translate'] = None):
     ''' Make copies of the selected bones within the same armature and move them
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param ARMATURE_OT_duplicate: Duplicate Selected Bone(s), Make copies of the selected bones within the same armature
-    :type ARMATURE_OT_duplicate: 'duplicate'
+    :type ARMATURE_OT_duplicate: typing.Optional['duplicate']
     :param TRANSFORM_OT_translate: Move, Move selected items
-    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
+    :type TRANSFORM_OT_translate: typing.Optional['bpy.ops.transform.translate']
     '''
 
     pass
@@ -213,38 +210,38 @@ def duplicate_move(
 def extrude(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None,
+            undo: typing.Optional[bool] = None,
             *,
-            forked: bool = False):
+            forked: typing.Union[bool, typing.Any] = False):
     ''' Create new bones from the selected joints
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param forked: Forked
-    :type forked: bool
+    :type forked: typing.Union[bool, typing.Any]
     '''
 
     pass
 
 
-def extrude_forked(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        ARMATURE_OT_extrude: 'extrude' = None,
-        TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
+def extrude_forked(override_context: typing.
+                   Union[typing.Dict, 'bpy.types.Context'] = None,
+                   execution_context: typing.Union[str, int] = None,
+                   undo: typing.Optional[bool] = None,
+                   *,
+                   ARMATURE_OT_extrude: typing.Optional['extrude'] = None,
+                   TRANSFORM_OT_translate: typing.
+                   Optional['bpy.ops.transform.translate'] = None):
     ''' Create new bones from the selected joints and move them
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param ARMATURE_OT_extrude: Extrude, Create new bones from the selected joints
-    :type ARMATURE_OT_extrude: 'extrude'
+    :type ARMATURE_OT_extrude: typing.Optional['extrude']
     :param TRANSFORM_OT_translate: Move, Move selected items
-    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
+    :type TRANSFORM_OT_translate: typing.Optional['bpy.ops.transform.translate']
     '''
 
     pass
@@ -253,19 +250,20 @@ def extrude_forked(
 def extrude_move(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 ARMATURE_OT_extrude: 'extrude' = None,
-                 TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
+                 ARMATURE_OT_extrude: typing.Optional['extrude'] = None,
+                 TRANSFORM_OT_translate: typing.
+                 Optional['bpy.ops.transform.translate'] = None):
     ''' Create new bones from the selected joints and move them
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param ARMATURE_OT_extrude: Extrude, Create new bones from the selected joints
-    :type ARMATURE_OT_extrude: 'extrude'
+    :type ARMATURE_OT_extrude: typing.Optional['extrude']
     :param TRANSFORM_OT_translate: Move, Move selected items
-    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
+    :type TRANSFORM_OT_translate: typing.Optional['bpy.ops.transform.translate']
     '''
 
     pass
@@ -274,12 +272,12 @@ def extrude_move(override_context: typing.
 def fill(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None):
+         undo: typing.Optional[bool] = None):
     ''' Add bone between selected joint(s) and/or 3D cursor
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -288,16 +286,16 @@ def fill(override_context: typing.Union[typing.
 def flip_names(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               do_strip_numbers: bool = False):
+               do_strip_numbers: typing.Union[bool, typing.Any] = False):
     ''' Flips (and corrects) the axis suffixes of the names of selected bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param do_strip_numbers: Strip Numbers, Try to remove right-most dot-number from flipped names. Warning: May result in incoherent naming in some cases
-    :type do_strip_numbers: bool
+    :type undo: typing.Optional[bool]
+    :param do_strip_numbers: May result in incoherent naming in some cases
+    :type do_strip_numbers: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -306,16 +304,16 @@ def flip_names(override_context: typing.
 def hide(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
+         undo: typing.Optional[bool] = None,
          *,
-         unselected: bool = False):
+         unselected: typing.Union[bool, typing.Any] = False):
     ''' Tag selected bones to not be visible in Edit Mode
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param unselected: Unselected, Hide unselected rather than selected
-    :type unselected: bool
+    :type unselected: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -324,16 +322,16 @@ def hide(override_context: typing.Union[typing.
 def layers_show_all(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    all: bool = True):
+                    all: typing.Union[bool, typing.Any] = True):
     ''' Make all armature layers visible
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all: All Layers, Enable all layers or just the first 16 (top row)
-    :type all: bool
+    :type all: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -342,16 +340,16 @@ def layers_show_all(override_context: typing.
 def parent_clear(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 type: typing.Union[str, int] = 'CLEAR'):
+                 type: typing.Optional[typing.Any] = 'CLEAR'):
     ''' Remove the parent-child relationship between selected bones and their parents
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Clear Type, What way to clear parenting
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -360,16 +358,16 @@ def parent_clear(override_context: typing.
 def parent_set(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               type: typing.Union[str, int] = 'CONNECTED'):
+               type: typing.Optional[typing.Any] = 'CONNECTED'):
     ''' Set the active bone as the parent of the selected bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Parent Type, Type of parenting
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -378,16 +376,16 @@ def parent_set(override_context: typing.
 def reveal(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None,
+           undo: typing.Optional[bool] = None,
            *,
-           select: bool = True):
+           select: typing.Union[bool, typing.Any] = True):
     ''' Reveal all bones hidden in Edit Mode
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param select: Select
-    :type select: bool
+    :type select: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -396,16 +394,16 @@ def reveal(override_context: typing.Union[typing.
 def roll_clear(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               roll: float = 0.0):
+               roll: typing.Optional[typing.Any] = 0.0):
     ''' Clear roll for selected bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param roll: Roll
-    :type roll: float
+    :type roll: typing.Optional[typing.Any]
     '''
 
     pass
@@ -414,16 +412,16 @@ def roll_clear(override_context: typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               action: typing.Union[str, int] = 'TOGGLE'):
+               action: typing.Optional[typing.Any] = 'TOGGLE'):
     ''' Toggle selection status of all bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
+    :type action: typing.Optional[typing.Any]
     '''
 
     pass
@@ -432,19 +430,19 @@ def select_all(override_context: typing.
 def select_hierarchy(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
+                     undo: typing.Optional[bool] = None,
                      *,
-                     direction: typing.Union[str, int] = 'PARENT',
-                     extend: bool = False):
+                     direction: typing.Optional[typing.Any] = 'PARENT',
+                     extend: typing.Union[bool, typing.Any] = False):
     ''' Select immediate parent/children of selected bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Optional[typing.Any]
     :param extend: Extend, Extend the selection
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -453,12 +451,12 @@ def select_hierarchy(override_context: typing.
 def select_less(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Deselect those bones at the boundary of each selection region
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -467,16 +465,16 @@ def select_less(override_context: typing.
 def select_linked(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  all_forks: bool = False):
+                  all_forks: typing.Union[bool, typing.Any] = False):
     ''' Select all bones linked by parent/child connections to the current selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all_forks: All Forks, Follow forks in the parents chain
-    :type all_forks: bool
+    :type all_forks: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -485,19 +483,19 @@ def select_linked(override_context: typing.
 def select_linked_pick(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: bool = None,
+                       undo: typing.Optional[bool] = None,
                        *,
-                       deselect: bool = False,
-                       all_forks: bool = False):
+                       deselect: typing.Union[bool, typing.Any] = False,
+                       all_forks: typing.Union[bool, typing.Any] = False):
     ''' (De)select bones linked by parent/child connections under the mouse cursor
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param deselect: Deselect
-    :type deselect: bool
+    :type deselect: typing.Union[bool, typing.Any]
     :param all_forks: All Forks, Follow forks in the parents chain
-    :type all_forks: bool
+    :type all_forks: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -506,19 +504,19 @@ def select_linked_pick(override_context: typing.
 def select_mirror(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  only_active: bool = False,
-                  extend: bool = False):
+                  only_active: typing.Union[bool, typing.Any] = False,
+                  extend: typing.Union[bool, typing.Any] = False):
     ''' Mirror the bone selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param only_active: Active Only, Only operate on the active bone
-    :type only_active: bool
+    :type only_active: typing.Union[bool, typing.Any]
     :param extend: Extend, Extend the selection
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -527,12 +525,12 @@ def select_mirror(override_context: typing.
 def select_more(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Select those bones connected to the initial selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -541,19 +539,19 @@ def select_more(override_context: typing.
 def select_similar(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   type: typing.Union[str, int] = 'LENGTH',
-                   threshold: float = 0.1):
+                   type: typing.Optional[typing.Any] = 'LENGTH',
+                   threshold: typing.Optional[typing.Any] = 0.1):
     ''' Select similar bones by property types
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     :param threshold: Threshold
-    :type threshold: float
+    :type threshold: typing.Optional[typing.Any]
     '''
 
     pass
@@ -562,12 +560,12 @@ def select_similar(override_context: typing.
 def separate(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Isolate selected bones into a separate armature
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -576,12 +574,12 @@ def separate(override_context: typing.Union[typing.
 def shortest_path_pick(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: bool = None):
+                       undo: typing.Optional[bool] = None):
     ''' Select shortest path between two bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -590,12 +588,12 @@ def shortest_path_pick(override_context: typing.
 def split(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
-          undo: bool = None):
+          undo: typing.Optional[bool] = None):
     ''' Split off selected bones from connected unselected bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -604,16 +602,16 @@ def split(override_context: typing.Union[typing.
 def subdivide(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
+              undo: typing.Optional[bool] = None,
               *,
-              number_cuts: int = 1):
+              number_cuts: typing.Optional[typing.Any] = 1):
     ''' Break selected bones into chains of smaller bones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param number_cuts: Number of Cuts
-    :type number_cuts: int
+    :type number_cuts: typing.Optional[typing.Any]
     '''
 
     pass
@@ -622,12 +620,12 @@ def subdivide(override_context: typing.Union[typing.
 def switch_direction(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Change the direction that a chain of bones points in (head and tail swap)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -636,16 +634,16 @@ def switch_direction(override_context: typing.
 def symmetrize(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               direction: typing.Union[str, int] = 'NEGATIVE_X'):
+               direction: typing.Optional[typing.Any] = 'NEGATIVE_X'):
     ''' Enforce symmetry, make copies of the selection or use existing
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param direction: Direction, Which sides to copy from and to (when both are selected)
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Optional[typing.Any]
     '''
 
     pass
