@@ -9,12 +9,12 @@ def convert_from_particle_system(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None):
+        undo: typing.Optional[bool] = None):
     ''' Add a new curves object based on the current state of the particle system
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -24,12 +24,12 @@ def convert_to_particle_system(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None):
+        undo: typing.Optional[bool] = None):
     ''' Add a new or update an existing hair particle system on the surface object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -38,12 +38,12 @@ def convert_to_particle_system(
 def disable_selection(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None):
+                      undo: typing.Optional[bool] = None):
     ''' Disable the drawing of influence of selection in sculpt mode
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -52,12 +52,12 @@ def disable_selection(override_context: typing.
 def sculptmode_toggle(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None):
+                      undo: typing.Optional[bool] = None):
     ''' Enter/Exit sculpt mode for curves
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -66,34 +66,35 @@ def sculptmode_toggle(override_context: typing.
 def set_selection_domain(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None,
+                         undo: typing.Optional[bool] = None,
                          *,
-                         domain: typing.Union[int, str] = 'POINT'):
+                         domain: typing.Union[str, int] = 'POINT'):
     ''' Change the mode used for selection masking in curves sculpt mode
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param domain: Domain
-    :type domain: typing.Union[int, str]
+    :type domain: typing.Union[str, int]
     '''
 
     pass
 
 
-def snap_curves_to_surface(override_context: typing.
-                           Union[typing.Dict, 'bpy.types.Context'] = None,
-                           execution_context: typing.Union[str, int] = None,
-                           undo: bool = None,
-                           *,
-                           attach_mode: typing.Union[str, int] = 'NEAREST'):
+def snap_curves_to_surface(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: typing.Optional[bool] = None,
+        *,
+        attach_mode: typing.Optional[typing.Any] = 'NEAREST'):
     ''' Move curves so that the first point is exactly on the surface mesh
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param attach_mode: Attach Mode, How to find the point on the surface to attach to * NEAREST Nearest -- Find the closest point on the surface for the root point of every curve and move the root there. * DEFORM Deform -- Re-attach curves to a deformed surface using the existing attachment information. This only works when the topology of the surface mesh has not changed.
-    :type attach_mode: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param attach_mode: Attach Mode, How to find the point on the surface to attach to * ``NEAREST`` Nearest -- Find the closest point on the surface for the root point of every curve and move the root there. * ``DEFORM`` Deform -- Re-attach curves to a deformed surface using the existing attachment information. This only works when the topology of the surface mesh has not changed.
+    :type attach_mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -102,12 +103,12 @@ def snap_curves_to_surface(override_context: typing.
 def surface_set(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Use the active object as surface for selected curves objects and set it as the parent
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
