@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def autopack_toggle(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None):
+                    undo: typing.Optional[bool] = None):
     ''' Automatically pack all external files into the .blend file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -22,12 +22,12 @@ def autopack_toggle(override_context: typing.
 def bookmark_add(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Add a bookmark for the selected/active directory
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -36,12 +36,12 @@ def bookmark_add(override_context: typing.
 def bookmark_cleanup(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Delete all invalid bookmarks
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -50,16 +50,16 @@ def bookmark_cleanup(override_context: typing.
 def bookmark_delete(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    index: int = -1):
+                    index: typing.Optional[typing.Any] = -1):
     ''' Delete selected bookmark
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param index: Index
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -68,16 +68,16 @@ def bookmark_delete(override_context: typing.
 def bookmark_move(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  direction: typing.Union[str, int] = 'TOP'):
+                  direction: typing.Optional[typing.Any] = 'TOP'):
     ''' Move the active bookmark up/down in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param direction: Direction, Direction to move the active bookmark towards * TOP Top -- Top of the list. * UP Up. * DOWN Down. * BOTTOM Bottom -- Bottom of the list.
-    :type direction: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param direction: Direction, Direction to move the active bookmark towards * ``TOP`` Top -- Top of the list. * ``UP`` Up. * ``DOWN`` Down. * ``BOTTOM`` Bottom -- Bottom of the list.
+    :type direction: typing.Optional[typing.Any]
     '''
 
     pass
@@ -86,12 +86,12 @@ def bookmark_move(override_context: typing.
 def cancel(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Cancel loading of selected file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -100,12 +100,12 @@ def cancel(override_context: typing.Union[typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Move selected files to the trash or recycle bin
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -114,22 +114,22 @@ def delete(override_context: typing.Union[typing.
 def directory_new(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  directory: str = "",
-                  open: bool = False,
-                  confirm: bool = True):
+                  directory: typing.Union[str, typing.Any] = "",
+                  open: typing.Union[bool, typing.Any] = False,
+                  confirm: typing.Union[bool, typing.Any] = True):
     ''' Create a new directory
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param directory: Directory, Name of new directory
-    :type directory: str
+    :type directory: typing.Union[str, typing.Any]
     :param open: Open, Open new directory
-    :type open: bool
+    :type open: typing.Union[bool, typing.Any]
     :param confirm: Confirm, Prompt for confirmation
-    :type confirm: bool
+    :type confirm: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -138,12 +138,12 @@ def directory_new(override_context: typing.
 def edit_directory_path(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None):
+                        undo: typing.Optional[bool] = None):
     ''' Start editing directory field
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -152,12 +152,12 @@ def edit_directory_path(override_context: typing.
 def execute(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None):
+            undo: typing.Optional[bool] = None):
     ''' Execute selected file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -166,16 +166,16 @@ def execute(override_context: typing.Union[typing.
 def filenum(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None,
+            undo: typing.Optional[bool] = None,
             *,
-            increment: int = 1):
+            increment: typing.Optional[typing.Any] = 1):
     ''' Increment number in filename
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param increment: Increment
-    :type increment: int
+    :type increment: typing.Optional[typing.Any]
     '''
 
     pass
@@ -184,99 +184,103 @@ def filenum(override_context: typing.Union[typing.
 def filepath_drop(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  filepath: str = "Path"):
-    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+                  filepath: typing.Union[str, typing.Any] = "Path"):
+    ''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :type filepath: str
+    :type undo: typing.Optional[bool]
+    :type filepath: typing.Union[str, typing.Any]
     '''
 
     pass
 
 
-def find_missing_files(override_context: typing.
-                       Union[typing.Dict, 'bpy.types.Context'] = None,
-                       execution_context: typing.Union[str, int] = None,
-                       undo: bool = None,
-                       *,
-                       find_all: bool = False,
-                       directory: str = "",
-                       hide_props_region: bool = True,
-                       filter_blender: bool = False,
-                       filter_backup: bool = False,
-                       filter_image: bool = False,
-                       filter_movie: bool = False,
-                       filter_python: bool = False,
-                       filter_font: bool = False,
-                       filter_sound: bool = False,
-                       filter_text: bool = False,
-                       filter_archive: bool = False,
-                       filter_btx: bool = False,
-                       filter_collada: bool = False,
-                       filter_alembic: bool = False,
-                       filter_usd: bool = False,
-                       filter_obj: bool = False,
-                       filter_volume: bool = False,
-                       filter_folder: bool = False,
-                       filter_blenlib: bool = False,
-                       filemode: int = 9,
-                       display_type: typing.Union[str, int] = 'DEFAULT',
-                       sort_method: typing.Union[str, int] = ''):
+def find_missing_files(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: typing.Optional[bool] = None,
+        *,
+        find_all: typing.Union[bool, typing.Any] = False,
+        directory: typing.Union[str, typing.Any] = "",
+        hide_props_region: typing.Union[bool, typing.Any] = True,
+        check_existing: typing.Union[bool, typing.Any] = False,
+        filter_blender: typing.Union[bool, typing.Any] = False,
+        filter_backup: typing.Union[bool, typing.Any] = False,
+        filter_image: typing.Union[bool, typing.Any] = False,
+        filter_movie: typing.Union[bool, typing.Any] = False,
+        filter_python: typing.Union[bool, typing.Any] = False,
+        filter_font: typing.Union[bool, typing.Any] = False,
+        filter_sound: typing.Union[bool, typing.Any] = False,
+        filter_text: typing.Union[bool, typing.Any] = False,
+        filter_archive: typing.Union[bool, typing.Any] = False,
+        filter_btx: typing.Union[bool, typing.Any] = False,
+        filter_collada: typing.Union[bool, typing.Any] = False,
+        filter_alembic: typing.Union[bool, typing.Any] = False,
+        filter_usd: typing.Union[bool, typing.Any] = False,
+        filter_obj: typing.Union[bool, typing.Any] = False,
+        filter_volume: typing.Union[bool, typing.Any] = False,
+        filter_folder: typing.Union[bool, typing.Any] = False,
+        filter_blenlib: typing.Union[bool, typing.Any] = False,
+        filemode: typing.Optional[typing.Any] = 9,
+        display_type: typing.Optional[typing.Any] = 'DEFAULT',
+        sort_method: typing.Union[str, int, typing.Any] = ''):
     ''' Try to find missing external files
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param find_all: Find All, Find all files in the search path (not just missing)
-    :type find_all: bool
+    :type find_all: typing.Union[bool, typing.Any]
     :param directory: Directory, Directory of the file
-    :type directory: str
+    :type directory: typing.Union[str, typing.Any]
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
+    :type hide_props_region: typing.Union[bool, typing.Any]
+    :param check_existing: Check Existing, Check and warn on overwriting existing files
+    :type check_existing: typing.Union[bool, typing.Any]
     :param filter_blender: Filter .blend files
-    :type filter_blender: bool
+    :type filter_blender: typing.Union[bool, typing.Any]
     :param filter_backup: Filter .blend files
-    :type filter_backup: bool
+    :type filter_backup: typing.Union[bool, typing.Any]
     :param filter_image: Filter image files
-    :type filter_image: bool
+    :type filter_image: typing.Union[bool, typing.Any]
     :param filter_movie: Filter movie files
-    :type filter_movie: bool
+    :type filter_movie: typing.Union[bool, typing.Any]
     :param filter_python: Filter python files
-    :type filter_python: bool
+    :type filter_python: typing.Union[bool, typing.Any]
     :param filter_font: Filter font files
-    :type filter_font: bool
+    :type filter_font: typing.Union[bool, typing.Any]
     :param filter_sound: Filter sound files
-    :type filter_sound: bool
+    :type filter_sound: typing.Union[bool, typing.Any]
     :param filter_text: Filter text files
-    :type filter_text: bool
+    :type filter_text: typing.Union[bool, typing.Any]
     :param filter_archive: Filter archive files
-    :type filter_archive: bool
+    :type filter_archive: typing.Union[bool, typing.Any]
     :param filter_btx: Filter btx files
-    :type filter_btx: bool
+    :type filter_btx: typing.Union[bool, typing.Any]
     :param filter_collada: Filter COLLADA files
-    :type filter_collada: bool
+    :type filter_collada: typing.Union[bool, typing.Any]
     :param filter_alembic: Filter Alembic files
-    :type filter_alembic: bool
+    :type filter_alembic: typing.Union[bool, typing.Any]
     :param filter_usd: Filter USD files
-    :type filter_usd: bool
+    :type filter_usd: typing.Union[bool, typing.Any]
     :param filter_obj: Filter OBJ files
-    :type filter_obj: bool
+    :type filter_obj: typing.Union[bool, typing.Any]
     :param filter_volume: Filter OpenVDB volume files
-    :type filter_volume: bool
+    :type filter_volume: typing.Union[bool, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_blenlib: Filter Blender IDs
-    :type filter_blenlib: bool
+    :type filter_blenlib: typing.Union[bool, typing.Any]
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
-    :type filemode: int
-    :param display_type: Display Type * DEFAULT Default -- Automatically determine display type for files. * LIST_VERTICAL Short List -- Display files as short list. * LIST_HORIZONTAL Long List -- Display files as a detailed list. * THUMBNAIL Thumbnails -- Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type filemode: typing.Optional[typing.Any]
+    :param display_type: Display Type * ``DEFAULT`` Default -- Automatically determine display type for files. * ``LIST_VERTICAL`` Short List -- Display files as short list. * ``LIST_HORIZONTAL`` Long List -- Display files as a detailed list. * ``THUMBNAIL`` Thumbnails -- Display files as thumbnails.
+    :type display_type: typing.Optional[typing.Any]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[str, int, typing.Any]
     '''
 
     pass
@@ -285,12 +289,12 @@ def find_missing_files(override_context: typing.
 def hidedot(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None):
+            undo: typing.Optional[bool] = None):
     ''' Toggle hide hidden dot files
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -299,12 +303,12 @@ def hidedot(override_context: typing.Union[typing.
 def highlight(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Highlight selected file(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -313,12 +317,12 @@ def highlight(override_context: typing.Union[typing.
 def make_paths_absolute(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None):
+                        undo: typing.Optional[bool] = None):
     ''' Make all paths to external files absolute
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -327,12 +331,12 @@ def make_paths_absolute(override_context: typing.
 def make_paths_relative(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None):
+                        undo: typing.Optional[bool] = None):
     ''' Make all paths to external files relative to current .blend
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -341,12 +345,12 @@ def make_paths_relative(override_context: typing.
 def mouse_execute(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Perform the current execute action for the file under the cursor (e.g. open the file)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -355,12 +359,12 @@ def mouse_execute(override_context: typing.
 def next(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: bool = None):
+         undo: typing.Optional[bool] = None):
     ''' Move to next folder
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -369,12 +373,12 @@ def next(override_context: typing.Union[typing.
 def pack_all(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Pack all used external files into this .blend
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -383,12 +387,12 @@ def pack_all(override_context: typing.Union[typing.
 def pack_libraries(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
+                   undo: typing.Optional[bool] = None):
     ''' Store all data-blocks linked from other .blend files in the current .blend file. Library references are preserved so the linked data-blocks can be unpacked again
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -397,12 +401,12 @@ def pack_libraries(override_context: typing.
 def parent(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Move to parent directory
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -411,12 +415,12 @@ def parent(override_context: typing.Union[typing.
 def previous(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
-             undo: bool = None):
+             undo: typing.Optional[bool] = None):
     ''' Move to previous folder
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -425,12 +429,12 @@ def previous(override_context: typing.Union[typing.
 def refresh(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None):
+            undo: typing.Optional[bool] = None):
     ''' Refresh the file list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -439,12 +443,12 @@ def refresh(override_context: typing.Union[typing.
 def rename(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Rename file or file directory
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -453,12 +457,12 @@ def rename(override_context: typing.Union[typing.
 def report_missing_files(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None):
+                         undo: typing.Optional[bool] = None):
     ''' Report all missing external files
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -467,12 +471,12 @@ def report_missing_files(override_context: typing.
 def reset_recent(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Reset recent files
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -481,40 +485,40 @@ def reset_recent(override_context: typing.
 def select(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None,
+           undo: typing.Optional[bool] = None,
            *,
-           wait_to_deselect_others: bool = False,
-           mouse_x: int = 0,
-           mouse_y: int = 0,
-           extend: bool = False,
-           fill: bool = False,
-           open: bool = True,
-           deselect_all: bool = False,
-           only_activate_if_selected: bool = False,
-           pass_through: bool = False):
+           wait_to_deselect_others: typing.Union[bool, typing.Any] = False,
+           mouse_x: typing.Optional[typing.Any] = 0,
+           mouse_y: typing.Optional[typing.Any] = 0,
+           extend: typing.Union[bool, typing.Any] = False,
+           fill: typing.Union[bool, typing.Any] = False,
+           open: typing.Union[bool, typing.Any] = True,
+           deselect_all: typing.Union[bool, typing.Any] = False,
+           only_activate_if_selected: typing.Union[bool, typing.Any] = False,
+           pass_through: typing.Union[bool, typing.Any] = False):
     ''' Handle mouse clicks to select and activate items
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param wait_to_deselect_others: Wait to Deselect Others
-    :type wait_to_deselect_others: bool
+    :type wait_to_deselect_others: typing.Union[bool, typing.Any]
     :param mouse_x: Mouse X
-    :type mouse_x: int
+    :type mouse_x: typing.Optional[typing.Any]
     :param mouse_y: Mouse Y
-    :type mouse_y: int
+    :type mouse_y: typing.Optional[typing.Any]
     :param extend: Extend, Extend selection instead of deselecting everything first
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     :param fill: Fill, Select everything beginning with the last selection
-    :type fill: bool
+    :type fill: typing.Union[bool, typing.Any]
     :param open: Open, Open a directory when selecting it
-    :type open: bool
+    :type open: typing.Union[bool, typing.Any]
     :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor
-    :type deselect_all: bool
+    :type deselect_all: typing.Union[bool, typing.Any]
     :param only_activate_if_selected: Only Activate if Selected, Do not change selection if the item under the cursor is already selected, only activate it
-    :type only_activate_if_selected: bool
+    :type only_activate_if_selected: typing.Union[bool, typing.Any]
     :param pass_through: Pass Through, Even on successful execution, pass the event on so other operators can execute on it as well
-    :type pass_through: bool
+    :type pass_through: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -523,16 +527,16 @@ def select(override_context: typing.Union[typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               action: typing.Union[str, int] = 'TOGGLE'):
+               action: typing.Optional[typing.Any] = 'TOGGLE'):
     ''' Select or deselect all files
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
+    :type action: typing.Optional[typing.Any]
     '''
 
     pass
@@ -541,16 +545,16 @@ def select_all(override_context: typing.
 def select_bookmark(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    dir: str = ""):
+                    dir: typing.Union[str, typing.Any] = ""):
     ''' Select a bookmarked directory
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param dir: Directory
-    :type dir: str
+    :type dir: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -559,31 +563,31 @@ def select_bookmark(override_context: typing.
 def select_box(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               xmin: int = 0,
-               xmax: int = 0,
-               ymin: int = 0,
-               ymax: int = 0,
-               wait_for_input: bool = True,
-               mode: typing.Union[str, int] = 'SET'):
+               xmin: typing.Optional[typing.Any] = 0,
+               xmax: typing.Optional[typing.Any] = 0,
+               ymin: typing.Optional[typing.Any] = 0,
+               ymax: typing.Optional[typing.Any] = 0,
+               wait_for_input: typing.Union[bool, typing.Any] = True,
+               mode: typing.Optional[typing.Any] = 'SET'):
     ''' Activate/select the file(s) contained in the border
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param xmin: X Min
-    :type xmin: int
+    :type xmin: typing.Optional[typing.Any]
     :param xmax: X Max
-    :type xmax: int
+    :type xmax: typing.Optional[typing.Any]
     :param ymin: Y Min
-    :type ymin: int
+    :type ymin: typing.Optional[typing.Any]
     :param ymax: Y Max
-    :type ymax: int
+    :type ymax: typing.Optional[typing.Any]
     :param wait_for_input: Wait for Input
-    :type wait_for_input: bool
-    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type wait_for_input: typing.Union[bool, typing.Any]
+    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
+    :type mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -592,22 +596,22 @@ def select_box(override_context: typing.
 def select_walk(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
+                undo: typing.Optional[bool] = None,
                 *,
-                direction: typing.Union[str, int] = 'UP',
-                extend: bool = False,
-                fill: bool = False):
+                direction: typing.Optional[typing.Any] = 'UP',
+                extend: typing.Union[bool, typing.Any] = False,
+                fill: typing.Union[bool, typing.Any] = False):
     ''' Select/Deselect files by walking through them
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param direction: Walk Direction, Select/Deselect element in this direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Optional[typing.Any]
     :param extend: Extend, Extend selection instead of deselecting everything first
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     :param fill: Fill, Select everything beginning with the last selection
-    :type fill: bool
+    :type fill: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -616,12 +620,12 @@ def select_walk(override_context: typing.
 def smoothscroll(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Smooth scroll to make editable file visible
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -630,12 +634,12 @@ def smoothscroll(override_context: typing.
 def sort_column_ui_context(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: bool = None):
+                           undo: typing.Optional[bool] = None):
     ''' Change sorting to use column under cursor
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -644,12 +648,12 @@ def sort_column_ui_context(override_context: typing.
 def start_filter(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Start entering filter text
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -658,16 +662,16 @@ def start_filter(override_context: typing.
 def unpack_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               method: typing.Union[str, int] = 'USE_LOCAL'):
+               method: typing.Optional[typing.Any] = 'USE_LOCAL'):
     ''' Unpack all files packed into this .blend to external ones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param method: Method, How to unpack
-    :type method: typing.Union[str, int]
+    :type method: typing.Optional[typing.Any]
     '''
 
     pass
@@ -676,22 +680,22 @@ def unpack_all(override_context: typing.
 def unpack_item(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
+                undo: typing.Optional[bool] = None,
                 *,
-                method: typing.Union[str, int] = 'USE_LOCAL',
-                id_name: str = "",
-                id_type: int = 19785):
+                method: typing.Optional[typing.Any] = 'USE_LOCAL',
+                id_name: typing.Union[str, typing.Any] = "",
+                id_type: typing.Optional[typing.Any] = 19785):
     ''' Unpack this file to an external file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param method: Method, How to unpack
-    :type method: typing.Union[str, int]
+    :type method: typing.Optional[typing.Any]
     :param id_name: ID Name, Name of ID block to unpack
-    :type id_name: str
+    :type id_name: typing.Union[str, typing.Any]
     :param id_type: ID Type, Identifier type of ID block
-    :type id_type: int
+    :type id_type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -700,12 +704,12 @@ def unpack_item(override_context: typing.
 def unpack_libraries(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Restore all packed linked data-blocks to their original locations
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -714,12 +718,12 @@ def unpack_libraries(override_context: typing.
 def view_selected(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Scroll the selected files into view
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
