@@ -148,6 +148,7 @@ def open(override_context: typing.Union[typing.
          *,
          filepath: typing.Union[str, typing.Any] = "",
          hide_props_region: typing.Union[bool, typing.Any] = True,
+         check_existing: typing.Union[bool, typing.Any] = False,
          filter_blender: typing.Union[bool, typing.Any] = False,
          filter_backup: typing.Union[bool, typing.Any] = False,
          filter_image: typing.Union[bool, typing.Any] = False,
@@ -178,6 +179,8 @@ def open(override_context: typing.Union[typing.
     :type filepath: typing.Union[str, typing.Any]
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: typing.Union[bool, typing.Any]
+    :param check_existing: Check Existing, Check and warn on overwriting existing files
+    :type check_existing: typing.Union[bool, typing.Any]
     :param filter_blender: Filter .blend files
     :type filter_blender: typing.Union[bool, typing.Any]
     :param filter_backup: Filter .blend files
@@ -349,6 +352,7 @@ def text_paste_from_file(
         *,
         filepath: typing.Union[str, typing.Any] = "",
         hide_props_region: typing.Union[bool, typing.Any] = True,
+        check_existing: typing.Union[bool, typing.Any] = False,
         filter_blender: typing.Union[bool, typing.Any] = False,
         filter_backup: typing.Union[bool, typing.Any] = False,
         filter_image: typing.Union[bool, typing.Any] = False,
@@ -378,6 +382,8 @@ def text_paste_from_file(
     :type filepath: typing.Union[str, typing.Any]
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: typing.Union[bool, typing.Any]
+    :param check_existing: Check Existing, Check and warn on overwriting existing files
+    :type check_existing: typing.Union[bool, typing.Any]
     :param filter_blender: Filter .blend files
     :type filter_blender: typing.Union[bool, typing.Any]
     :param filter_backup: Filter .blend files
