@@ -1,7 +1,6 @@
 import sys
 import typing
 import bpy.types
-import mathutils
 
 GenericType = typing.TypeVar("GenericType")
 
@@ -9,22 +8,22 @@ GenericType = typing.TypeVar("GenericType")
 def attribute_add(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  name: str = "Attribute",
-                  domain: typing.Union[int, str] = 'POINT',
-                  data_type: typing.Union[int, str] = 'FLOAT'):
+                  name: typing.Union[str, typing.Any] = "Attribute",
+                  domain: typing.Union[str, int] = 'POINT',
+                  data_type: typing.Union[str, int] = 'FLOAT'):
     ''' Add attribute to geometry
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param name: Name, Name of new attribute
-    :type name: str
+    :type name: typing.Union[str, typing.Any]
     :param domain: Domain, Type of element that attribute is stored on
-    :type domain: typing.Union[int, str]
+    :type domain: typing.Union[str, int]
     :param data_type: Data Type, Type of data stored in attribute
-    :type data_type: typing.Union[int, str]
+    :type data_type: typing.Union[str, int]
     '''
 
     pass
@@ -33,22 +32,22 @@ def attribute_add(override_context: typing.
 def attribute_convert(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None,
+                      undo: typing.Optional[bool] = None,
                       *,
-                      mode: typing.Union[str, int] = 'GENERIC',
-                      domain: typing.Union[int, str] = 'POINT',
-                      data_type: typing.Union[int, str] = 'FLOAT'):
+                      mode: typing.Optional[typing.Any] = 'GENERIC',
+                      domain: typing.Union[str, int] = 'POINT',
+                      data_type: typing.Union[str, int] = 'FLOAT'):
     ''' Change how the attribute is stored
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Optional[typing.Any]
     :param domain: Domain, Which geometry element to move the attribute to
-    :type domain: typing.Union[int, str]
+    :type domain: typing.Union[str, int]
     :param data_type: Data Type
-    :type data_type: typing.Union[int, str]
+    :type data_type: typing.Union[str, int]
     '''
 
     pass
@@ -57,45 +56,40 @@ def attribute_convert(override_context: typing.
 def attribute_remove(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Remove attribute from geometry
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def color_attribute_add(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        name: str = "Color",
-        domain: typing.Union[int, str] = 'POINT',
-        data_type: typing.Union[int, str] = 'FLOAT_COLOR',
-        color: typing.
-        Union[typing.List[float], typing.
-              Tuple[float, float, float, float], 'mathutils.Vector'] = (0.0,
-                                                                        0.0,
-                                                                        0.0,
-                                                                        1.0)):
+def color_attribute_add(override_context: typing.
+                        Union[typing.Dict, 'bpy.types.Context'] = None,
+                        execution_context: typing.Union[str, int] = None,
+                        undo: typing.Optional[bool] = None,
+                        *,
+                        name: typing.Union[str, typing.Any] = "Color",
+                        domain: typing.Union[str, int] = 'POINT',
+                        data_type: typing.Union[str, int] = 'FLOAT_COLOR',
+                        color: typing.Optional[typing.Any] = (0.0, 0.0, 0.0,
+                                                              1.0)):
     ''' Add color attribute to geometry
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param name: Name, Name of new color attribute
-    :type name: str
+    :type name: typing.Union[str, typing.Any]
     :param domain: Domain, Type of element that attribute is stored on
-    :type domain: typing.Union[int, str]
+    :type domain: typing.Union[str, int]
     :param data_type: Data Type, Type of data stored in attribute
-    :type data_type: typing.Union[int, str]
+    :type data_type: typing.Union[str, int]
     :param color: Color, Default fill color
-    :type color: typing.Union[typing.List[float], typing.Tuple[float, float, float, float], 'mathutils.Vector']
+    :type color: typing.Optional[typing.Any]
     '''
 
     pass
@@ -104,12 +98,12 @@ def color_attribute_add(
 def color_attribute_duplicate(override_context: typing.
                               Union[typing.Dict, 'bpy.types.Context'] = None,
                               execution_context: typing.Union[str, int] = None,
-                              undo: bool = None):
+                              undo: typing.Optional[bool] = None):
     ''' Duplicate color attribute
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -118,12 +112,12 @@ def color_attribute_duplicate(override_context: typing.
 def color_attribute_remove(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: bool = None):
+                           undo: typing.Optional[bool] = None):
     ''' Remove color attribute from geometry
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -133,16 +127,16 @@ def color_attribute_render_set(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
+        undo: typing.Optional[bool] = None,
         *,
-        name: str = "Color"):
+        name: typing.Union[str, typing.Any] = "Color"):
     ''' Set default color attribute used for rendering
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param name: Name, Name of color attribute
-    :type name: str
+    :type name: typing.Union[str, typing.Any]
     '''
 
     pass
