@@ -20,6 +20,7 @@ def fbx(override_context: typing.Union[typing.
         global_scale: typing.Optional[typing.Any] = 1.0,
         bake_space_transform: typing.Union[bool, typing.Any] = False,
         use_custom_normals: typing.Union[bool, typing.Any] = True,
+        colors_type: typing.Optional[typing.Any] = 'SRGB',
         use_image_search: typing.Union[bool, typing.Any] = True,
         use_alpha_decals: typing.Union[bool, typing.Any] = False,
         decal_offset: typing.Optional[typing.Any] = 0.0,
@@ -59,7 +60,9 @@ def fbx(override_context: typing.Union[typing.
     :type bake_space_transform: typing.Union[bool, typing.Any]
     :param use_custom_normals: Custom Normals, Import custom normals, if available (otherwise Blender will recompute them)
     :type use_custom_normals: typing.Union[bool, typing.Any]
-    :param use_image_search: Image Search, Search subdirs for any associated images (WARNING: may be slow)
+    :param colors_type: Vertex Colors, Import vertex color attributes * ``NONE`` None -- Do not import color attributes. * ``SRGB`` sRGB -- Expect file colors in sRGB color space. * ``LINEAR`` Linear -- Expect file colors in linear color space.
+    :type colors_type: typing.Optional[typing.Any]
+    :param use_image_search: may be slow)
     :type use_image_search: typing.Union[bool, typing.Any]
     :param use_alpha_decals: Alpha Decals, Treat materials with alpha as decals (no shadow casting)
     :type use_alpha_decals: typing.Union[bool, typing.Any]
@@ -102,6 +105,7 @@ def gltf(override_context: typing.Union[typing.
          undo: typing.Optional[bool] = None,
          *,
          filepath: typing.Union[str, typing.Any] = "",
+         convert_lighting_mode: typing.Optional[typing.Any] = 'SPEC',
          filter_glob: typing.Union[str, typing.Any] = "*.glb;*.gltf",
          files: typing.Optional[bpy.types.bpy_prop_collection[
              'bpy.types.OperatorFileListElement']] = None,
@@ -118,6 +122,8 @@ def gltf(override_context: typing.Union[typing.
     :type undo: typing.Optional[bool]
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: typing.Union[str, typing.Any]
+    :param convert_lighting_mode: Lighting Mode, Optional backwards compatibility for non-standard render engines. Applies to lights * ``SPEC`` Standard -- Physically-based glTF lighting units (cd, lx, nt). * ``COMPAT`` Unitless -- Non-physical, unitless lighting. Useful when exposure controls are not available. * ``RAW`` Raw (Deprecated) -- Blender lighting strengths with no conversion.
+    :type convert_lighting_mode: typing.Optional[typing.Any]
     :param filter_glob: filter_glob
     :type filter_glob: typing.Union[str, typing.Any]
     :param files: File Path
