@@ -1,28 +1,24 @@
 import sys
 import typing
 import bpy.types
-import mathutils
 import bpy.ops.transform
 
 GenericType = typing.TypeVar("GenericType")
 
 
-def add_feather_vertex(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        location: typing.Union[typing.List[float], typing.
-                               Tuple[float, float], 'mathutils.Vector'] = (
-                                   0.0, 0.0)):
+def add_feather_vertex(override_context: typing.
+                       Union[typing.Dict, 'bpy.types.Context'] = None,
+                       execution_context: typing.Union[str, int] = None,
+                       undo: typing.Optional[bool] = None,
+                       *,
+                       location: typing.Optional[typing.Any] = (0.0, 0.0)):
     ''' Add vertex to feather
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param location: Location, Location of vertex in normalized space
-    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
+    :type location: typing.Optional[typing.Any]
     '''
 
     pass
@@ -32,61 +28,60 @@ def add_feather_vertex_slide(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
+        undo: typing.Optional[bool] = None,
         *,
-        MASK_OT_add_feather_vertex: 'add_feather_vertex' = None,
-        MASK_OT_slide_point: 'slide_point' = None):
+        MASK_OT_add_feather_vertex: typing.
+        Optional['add_feather_vertex'] = None,
+        MASK_OT_slide_point: typing.Optional['slide_point'] = None):
     ''' Add new vertex to feather and slide it
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param MASK_OT_add_feather_vertex: Add Feather Vertex, Add vertex to feather
-    :type MASK_OT_add_feather_vertex: 'add_feather_vertex'
+    :type MASK_OT_add_feather_vertex: typing.Optional['add_feather_vertex']
     :param MASK_OT_slide_point: Slide Point, Slide control points
-    :type MASK_OT_slide_point: 'slide_point'
+    :type MASK_OT_slide_point: typing.Optional['slide_point']
     '''
 
     pass
 
 
-def add_vertex(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        location: typing.Union[typing.List[float], typing.
-                               Tuple[float, float], 'mathutils.Vector'] = (
-                                   0.0, 0.0)):
+def add_vertex(override_context: typing.
+               Union[typing.Dict, 'bpy.types.Context'] = None,
+               execution_context: typing.Union[str, int] = None,
+               undo: typing.Optional[bool] = None,
+               *,
+               location: typing.Optional[typing.Any] = (0.0, 0.0)):
     ''' Add vertex to active spline
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param location: Location, Location of vertex in normalized space
-    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
+    :type location: typing.Optional[typing.Any]
     '''
 
     pass
 
 
-def add_vertex_slide(override_context: typing.
-                     Union[typing.Dict, 'bpy.types.Context'] = None,
-                     execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
-                     *,
-                     MASK_OT_add_vertex: 'add_vertex' = None,
-                     MASK_OT_slide_point: 'slide_point' = None):
+def add_vertex_slide(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: typing.Optional[bool] = None,
+        *,
+        MASK_OT_add_vertex: typing.Optional['add_vertex'] = None,
+        MASK_OT_slide_point: typing.Optional['slide_point'] = None):
     ''' Add new vertex and slide it
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param MASK_OT_add_vertex: Add Vertex, Add vertex to active spline
-    :type MASK_OT_add_vertex: 'add_vertex'
+    :type MASK_OT_add_vertex: typing.Optional['add_vertex']
     :param MASK_OT_slide_point: Slide Point, Slide control points
-    :type MASK_OT_slide_point: 'slide_point'
+    :type MASK_OT_slide_point: typing.Optional['slide_point']
     '''
 
     pass
@@ -95,12 +90,12 @@ def add_vertex_slide(override_context: typing.
 def copy_splines(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Copy selected splines to clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -109,12 +104,12 @@ def copy_splines(override_context: typing.
 def cyclic_toggle(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Toggle cyclic for selected splines
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -123,12 +118,12 @@ def cyclic_toggle(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Delete selected control points or splines
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -137,34 +132,34 @@ def delete(override_context: typing.Union[typing.
 def duplicate(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Duplicate selected control points and segments between them
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def duplicate_move(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        MASK_OT_duplicate: 'duplicate' = None,
-        TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
+def duplicate_move(override_context: typing.
+                   Union[typing.Dict, 'bpy.types.Context'] = None,
+                   execution_context: typing.Union[str, int] = None,
+                   undo: typing.Optional[bool] = None,
+                   *,
+                   MASK_OT_duplicate: typing.Optional['duplicate'] = None,
+                   TRANSFORM_OT_translate: typing.
+                   Optional['bpy.ops.transform.translate'] = None):
     ''' Duplicate mask and move
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param MASK_OT_duplicate: Duplicate Mask, Duplicate selected control points and segments between them
-    :type MASK_OT_duplicate: 'duplicate'
+    :type MASK_OT_duplicate: typing.Optional['duplicate']
     :param TRANSFORM_OT_translate: Move, Move selected items
-    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
+    :type TRANSFORM_OT_translate: typing.Optional['bpy.ops.transform.translate']
     '''
 
     pass
@@ -173,12 +168,12 @@ def duplicate_move(
 def feather_weight_clear(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None):
+                         undo: typing.Optional[bool] = None):
     ''' Reset the feather weight to zero
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -187,16 +182,16 @@ def feather_weight_clear(override_context: typing.
 def handle_type_set(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    type: typing.Union[str, int] = 'AUTO'):
+                    type: typing.Optional[typing.Any] = 'AUTO'):
     ''' Set type of handles for selected control points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Type, Spline type
-    :type type: typing.Union[str, int]
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -205,16 +200,16 @@ def handle_type_set(override_context: typing.
 def hide_view_clear(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    select: bool = True):
+                    select: typing.Union[bool, typing.Any] = True):
     ''' Reveal the layer by setting the hide flag
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param select: Select
-    :type select: bool
+    :type select: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -223,16 +218,16 @@ def hide_view_clear(override_context: typing.
 def hide_view_set(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  unselected: bool = False):
+                  unselected: typing.Union[bool, typing.Any] = False):
     ''' Hide the layer by setting the hide flag
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param unselected: Unselected, Hide unselected rather than selected layers
-    :type unselected: bool
+    :type unselected: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -241,16 +236,16 @@ def hide_view_set(override_context: typing.
 def layer_move(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               direction: typing.Union[str, int] = 'UP'):
+               direction: typing.Optional[typing.Any] = 'UP'):
     ''' Move the active layer up/down in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param direction: Direction, Direction to move the active layer
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Optional[typing.Any]
     '''
 
     pass
@@ -259,16 +254,16 @@ def layer_move(override_context: typing.
 def layer_new(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
+              undo: typing.Optional[bool] = None,
               *,
-              name: str = ""):
+              name: typing.Union[str, typing.Any] = ""):
     ''' Add new mask layer for masking
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param name: Name, Name of new mask layer
-    :type name: str
+    :type name: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -277,12 +272,12 @@ def layer_new(override_context: typing.Union[typing.
 def layer_remove(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Remove mask layer
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -291,16 +286,16 @@ def layer_remove(override_context: typing.
 def new(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
+        undo: typing.Optional[bool] = None,
         *,
-        name: str = ""):
+        name: typing.Union[str, typing.Any] = ""):
     ''' Create new mask
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param name: Name, Name of new mask
-    :type name: str
+    :type name: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -309,12 +304,12 @@ def new(override_context: typing.Union[typing.
 def normals_make_consistent(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: bool = None):
+                            undo: typing.Optional[bool] = None):
     ''' Recalculate the direction of selected handles
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -323,12 +318,12 @@ def normals_make_consistent(override_context: typing.
 def parent_clear(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Clear the mask's parenting
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -337,12 +332,12 @@ def parent_clear(override_context: typing.
 def parent_set(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None):
+               undo: typing.Optional[bool] = None):
     ''' Set the mask's parenting
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -351,60 +346,54 @@ def parent_set(override_context: typing.
 def paste_splines(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Paste splines from clipboard
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
 
 
-def primitive_circle_add(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        size: float = 100.0,
-        location: typing.Union[typing.List[float], typing.
-                               Tuple[float, float], 'mathutils.Vector'] = (
-                                   0.0, 0.0)):
+def primitive_circle_add(override_context: typing.
+                         Union[typing.Dict, 'bpy.types.Context'] = None,
+                         execution_context: typing.Union[str, int] = None,
+                         undo: typing.Optional[bool] = None,
+                         *,
+                         size: typing.Optional[typing.Any] = 100.0,
+                         location: typing.Optional[typing.Any] = (0.0, 0.0)):
     ''' Add new circle-shaped spline
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param size: Size, Size of new circle
-    :type size: float
+    :type size: typing.Optional[typing.Any]
     :param location: Location, Location of new circle
-    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
+    :type location: typing.Optional[typing.Any]
     '''
 
     pass
 
 
-def primitive_square_add(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        size: float = 100.0,
-        location: typing.Union[typing.List[float], typing.
-                               Tuple[float, float], 'mathutils.Vector'] = (
-                                   0.0, 0.0)):
+def primitive_square_add(override_context: typing.
+                         Union[typing.Dict, 'bpy.types.Context'] = None,
+                         execution_context: typing.Union[str, int] = None,
+                         undo: typing.Optional[bool] = None,
+                         *,
+                         size: typing.Optional[typing.Any] = 100.0,
+                         location: typing.Optional[typing.Any] = (0.0, 0.0)):
     ''' Add new square-shaped spline
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param size: Size, Size of new circle
-    :type size: float
+    :type size: typing.Optional[typing.Any]
     :param location: Location, Location of new circle
-    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
+    :type location: typing.Optional[typing.Any]
     '''
 
     pass
@@ -413,33 +402,31 @@ def primitive_square_add(
 def select(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None,
+           undo: typing.Optional[bool] = None,
            *,
-           extend: bool = False,
-           deselect: bool = False,
-           toggle: bool = False,
-           deselect_all: bool = False,
-           select_passthrough: bool = False,
-           location: typing.Union[typing.List[float], typing.
-                                  Tuple[float, float], 'mathutils.Vector'] = (
-                                      0.0, 0.0)):
+           extend: typing.Union[bool, typing.Any] = False,
+           deselect: typing.Union[bool, typing.Any] = False,
+           toggle: typing.Union[bool, typing.Any] = False,
+           deselect_all: typing.Union[bool, typing.Any] = False,
+           select_passthrough: typing.Union[bool, typing.Any] = False,
+           location: typing.Optional[typing.Any] = (0.0, 0.0)):
     ''' Select spline points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param extend: Extend, Extend selection instead of deselecting everything first
-    :type extend: bool
+    :type extend: typing.Union[bool, typing.Any]
     :param deselect: Deselect, Remove from selection
-    :type deselect: bool
+    :type deselect: typing.Union[bool, typing.Any]
     :param toggle: Toggle Selection, Toggle the selection
-    :type toggle: bool
+    :type toggle: typing.Union[bool, typing.Any]
     :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor
-    :type deselect_all: bool
+    :type deselect_all: typing.Union[bool, typing.Any]
     :param select_passthrough: Only Select Unselected, Ignore the select action when the element is already selected
-    :type select_passthrough: bool
+    :type select_passthrough: typing.Union[bool, typing.Any]
     :param location: Location, Location of vertex in normalized space
-    :type location: typing.Union[typing.List[float], typing.Tuple[float, float], 'mathutils.Vector']
+    :type location: typing.Optional[typing.Any]
     '''
 
     pass
@@ -448,16 +435,16 @@ def select(override_context: typing.Union[typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               action: typing.Union[str, int] = 'TOGGLE'):
+               action: typing.Optional[typing.Any] = 'TOGGLE'):
     ''' Change selection of all curve points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
+    :type action: typing.Optional[typing.Any]
     '''
 
     pass
@@ -466,31 +453,31 @@ def select_all(override_context: typing.
 def select_box(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               xmin: int = 0,
-               xmax: int = 0,
-               ymin: int = 0,
-               ymax: int = 0,
-               wait_for_input: bool = True,
-               mode: typing.Union[str, int] = 'SET'):
+               xmin: typing.Optional[typing.Any] = 0,
+               xmax: typing.Optional[typing.Any] = 0,
+               ymin: typing.Optional[typing.Any] = 0,
+               ymax: typing.Optional[typing.Any] = 0,
+               wait_for_input: typing.Union[bool, typing.Any] = True,
+               mode: typing.Optional[typing.Any] = 'SET'):
     ''' Select curve points using box selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param xmin: X Min
-    :type xmin: int
+    :type xmin: typing.Optional[typing.Any]
     :param xmax: X Max
-    :type xmax: int
+    :type xmax: typing.Optional[typing.Any]
     :param ymin: Y Min
-    :type ymin: int
+    :type ymin: typing.Optional[typing.Any]
     :param ymax: Y Max
-    :type ymax: int
+    :type ymax: typing.Optional[typing.Any]
     :param wait_for_input: Wait for Input
-    :type wait_for_input: bool
-    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type wait_for_input: typing.Union[bool, typing.Any]
+    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
+    :type mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -499,28 +486,28 @@ def select_box(override_context: typing.
 def select_circle(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  x: int = 0,
-                  y: int = 0,
-                  radius: int = 25,
-                  wait_for_input: bool = True,
-                  mode: typing.Union[str, int] = 'SET'):
+                  x: typing.Optional[typing.Any] = 0,
+                  y: typing.Optional[typing.Any] = 0,
+                  radius: typing.Optional[typing.Any] = 25,
+                  wait_for_input: typing.Union[bool, typing.Any] = True,
+                  mode: typing.Optional[typing.Any] = 'SET'):
     ''' Select curve points using circle selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param x: X
-    :type x: int
+    :type x: typing.Optional[typing.Any]
     :param y: Y
-    :type y: int
+    :type y: typing.Optional[typing.Any]
     :param radius: Radius
-    :type radius: int
+    :type radius: typing.Optional[typing.Any]
     :param wait_for_input: Wait for Input
-    :type wait_for_input: bool
-    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type wait_for_input: typing.Union[bool, typing.Any]
+    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
+    :type mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -529,20 +516,20 @@ def select_circle(override_context: typing.
 def select_lasso(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 path: bpy.types.
-                 bpy_prop_collection['bpy.types.OperatorMousePath'] = None,
-                 mode: typing.Union[str, int] = 'SET'):
+                 path: typing.Optional[bpy.types.bpy_prop_collection[
+                     'bpy.types.OperatorMousePath']] = None,
+                 mode: typing.Optional[typing.Any] = 'SET'):
     ''' Select curve points using lasso selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param path: Path
-    :type path: bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']
-    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type path: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']]
+    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
+    :type mode: typing.Optional[typing.Any]
     '''
 
     pass
@@ -551,12 +538,12 @@ def select_lasso(override_context: typing.
 def select_less(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Deselect spline points at the boundary of each selection region
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -565,12 +552,12 @@ def select_less(override_context: typing.
 def select_linked(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Select all curve points linked to already selected ones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -579,16 +566,16 @@ def select_linked(override_context: typing.
 def select_linked_pick(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: bool = None,
+                       undo: typing.Optional[bool] = None,
                        *,
-                       deselect: bool = False):
+                       deselect: typing.Union[bool, typing.Any] = False):
     ''' (De)select all points linked to the curve under the mouse cursor
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param deselect: Deselect
-    :type deselect: bool
+    :type deselect: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -597,12 +584,12 @@ def select_linked_pick(override_context: typing.
 def select_more(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
+                undo: typing.Optional[bool] = None):
     ''' Select more spline points connected to initial selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -611,12 +598,12 @@ def select_more(override_context: typing.
 def shape_key_clear(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None):
+                    undo: typing.Optional[bool] = None):
     ''' Remove mask shape keyframe for active mask layer at the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -625,12 +612,12 @@ def shape_key_clear(override_context: typing.
 def shape_key_feather_reset(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: bool = None):
+                            undo: typing.Optional[bool] = None):
     ''' Reset feather weights on all selected points animation values
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -639,12 +626,12 @@ def shape_key_feather_reset(override_context: typing.
 def shape_key_insert(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Insert mask shape keyframe for active mask layer at the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -653,19 +640,19 @@ def shape_key_insert(override_context: typing.
 def shape_key_rekey(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    location: bool = True,
-                    feather: bool = True):
+                    location: typing.Union[bool, typing.Any] = True,
+                    feather: typing.Union[bool, typing.Any] = True):
     ''' Recalculate animation data on selected points for frames selected in the dopesheet
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param location: Location
-    :type location: bool
+    :type location: typing.Union[bool, typing.Any]
     :param feather: Feather
-    :type feather: bool
+    :type feather: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -674,19 +661,19 @@ def shape_key_rekey(override_context: typing.
 def slide_point(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
+                undo: typing.Optional[bool] = None,
                 *,
-                slide_feather: bool = False,
-                is_new_point: bool = False):
+                slide_feather: typing.Union[bool, typing.Any] = False,
+                is_new_point: typing.Union[bool, typing.Any] = False):
     ''' Slide control points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param slide_feather: Slide Feather, First try to slide feather instead of vertex
-    :type slide_feather: bool
+    :type slide_feather: typing.Union[bool, typing.Any]
     :param is_new_point: Slide New Point, Newly created vertex is being slid
-    :type is_new_point: bool
+    :type is_new_point: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -695,12 +682,12 @@ def slide_point(override_context: typing.
 def slide_spline_curvature(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: bool = None):
+                           undo: typing.Optional[bool] = None):
     ''' Slide a point on the spline to define its curvature
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -709,12 +696,12 @@ def slide_spline_curvature(override_context: typing.
 def switch_direction(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Switch direction of selected splines
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
