@@ -8,16 +8,16 @@ GenericType = typing.TypeVar("GenericType")
 def addon_disable(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  module: str = ""):
+                  module: typing.Union[str, typing.Any] = ""):
     ''' Disable an add-on
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param module: Module, Module name of the add-on to disable
-    :type module: str
+    :type module: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -26,16 +26,16 @@ def addon_disable(override_context: typing.
 def addon_enable(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 module: str = ""):
+                 module: typing.Union[str, typing.Any] = ""):
     ''' Enable an add-on
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param module: Module, Module name of the add-on to enable
-    :type module: str
+    :type module: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -44,16 +44,16 @@ def addon_enable(override_context: typing.
 def addon_expand(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 module: str = ""):
+                 module: typing.Union[str, typing.Any] = ""):
     ''' Display information and preferences for this add-on
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param module: Module, Module name of the add-on to expand
-    :type module: str
+    :type module: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -62,31 +62,31 @@ def addon_expand(override_context: typing.
 def addon_install(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  overwrite: bool = True,
-                  target: typing.Union[str, int] = 'DEFAULT',
-                  filepath: str = "",
-                  filter_folder: bool = True,
-                  filter_python: bool = True,
-                  filter_glob: str = "*.py;*.zip"):
+                  overwrite: typing.Union[bool, typing.Any] = True,
+                  target: typing.Optional[typing.Any] = 'DEFAULT',
+                  filepath: typing.Union[str, typing.Any] = "",
+                  filter_folder: typing.Union[bool, typing.Any] = True,
+                  filter_python: typing.Union[bool, typing.Any] = True,
+                  filter_glob: typing.Union[str, typing.Any] = "*.py;*.zip"):
     ''' Install an add-on
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param overwrite: Overwrite, Remove existing add-ons with the same ID
-    :type overwrite: bool
+    :type overwrite: typing.Union[bool, typing.Any]
     :param target: Target Path
-    :type target: typing.Union[str, int]
+    :type target: typing.Optional[typing.Any]
     :param filepath: filepath
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_python: Filter python
-    :type filter_python: bool
+    :type filter_python: typing.Union[bool, typing.Any]
     :param filter_glob: filter_glob
-    :type filter_glob: str
+    :type filter_glob: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -95,12 +95,12 @@ def addon_install(override_context: typing.
 def addon_refresh(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
-    ''' Scan add-on directories for new modules :file: startup/bl_operators/userpref.py\:557 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$557> _
+                  undo: typing.Optional[bool] = None):
+    ''' Scan add-on directories for new modules :file: `startup/bl_operators/userpref.py\:570 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$570>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -109,16 +109,16 @@ def addon_refresh(override_context: typing.
 def addon_remove(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 module: str = ""):
+                 module: typing.Union[str, typing.Any] = ""):
     ''' Delete the add-on from the file system
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param module: Module, Module name of the add-on to remove
-    :type module: str
+    :type module: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -127,16 +127,16 @@ def addon_remove(override_context: typing.
 def addon_show(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               module: str = ""):
+               module: typing.Union[str, typing.Any] = ""):
     ''' Show add-on preferences
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param module: Module, Module name of the add-on to expand
-    :type module: str
+    :type module: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -145,25 +145,25 @@ def addon_show(override_context: typing.
 def app_template_install(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None,
+                         undo: typing.Optional[bool] = None,
                          *,
-                         overwrite: bool = True,
-                         filepath: str = "",
-                         filter_folder: bool = True,
-                         filter_glob: str = "*.zip"):
+                         overwrite: typing.Union[bool, typing.Any] = True,
+                         filepath: typing.Union[str, typing.Any] = "",
+                         filter_folder: typing.Union[bool, typing.Any] = True,
+                         filter_glob: typing.Union[str, typing.Any] = "*.zip"):
     ''' Install an application template
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param overwrite: Overwrite, Remove existing template with the same ID
-    :type overwrite: bool
+    :type overwrite: typing.Union[bool, typing.Any]
     :param filepath: filepath
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_glob: filter_glob
-    :type filter_glob: str
+    :type filter_glob: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -172,79 +172,82 @@ def app_template_install(override_context: typing.
 def asset_library_add(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None,
+                      undo: typing.Optional[bool] = None,
                       *,
-                      directory: str = "",
-                      hide_props_region: bool = True,
-                      filter_blender: bool = False,
-                      filter_backup: bool = False,
-                      filter_image: bool = False,
-                      filter_movie: bool = False,
-                      filter_python: bool = False,
-                      filter_font: bool = False,
-                      filter_sound: bool = False,
-                      filter_text: bool = False,
-                      filter_archive: bool = False,
-                      filter_btx: bool = False,
-                      filter_collada: bool = False,
-                      filter_alembic: bool = False,
-                      filter_usd: bool = False,
-                      filter_obj: bool = False,
-                      filter_volume: bool = False,
-                      filter_folder: bool = True,
-                      filter_blenlib: bool = False,
-                      filemode: int = 9,
-                      display_type: typing.Union[str, int] = 'DEFAULT',
-                      sort_method: typing.Union[str, int] = ''):
+                      directory: typing.Union[str, typing.Any] = "",
+                      hide_props_region: typing.Union[bool, typing.Any] = True,
+                      check_existing: typing.Union[bool, typing.Any] = False,
+                      filter_blender: typing.Union[bool, typing.Any] = False,
+                      filter_backup: typing.Union[bool, typing.Any] = False,
+                      filter_image: typing.Union[bool, typing.Any] = False,
+                      filter_movie: typing.Union[bool, typing.Any] = False,
+                      filter_python: typing.Union[bool, typing.Any] = False,
+                      filter_font: typing.Union[bool, typing.Any] = False,
+                      filter_sound: typing.Union[bool, typing.Any] = False,
+                      filter_text: typing.Union[bool, typing.Any] = False,
+                      filter_archive: typing.Union[bool, typing.Any] = False,
+                      filter_btx: typing.Union[bool, typing.Any] = False,
+                      filter_collada: typing.Union[bool, typing.Any] = False,
+                      filter_alembic: typing.Union[bool, typing.Any] = False,
+                      filter_usd: typing.Union[bool, typing.Any] = False,
+                      filter_obj: typing.Union[bool, typing.Any] = False,
+                      filter_volume: typing.Union[bool, typing.Any] = False,
+                      filter_folder: typing.Union[bool, typing.Any] = True,
+                      filter_blenlib: typing.Union[bool, typing.Any] = False,
+                      filemode: typing.Optional[typing.Any] = 9,
+                      display_type: typing.Optional[typing.Any] = 'DEFAULT',
+                      sort_method: typing.Union[str, int, typing.Any] = ''):
     ''' Add a directory to be used by the Asset Browser as source of assets
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param directory: Directory, Directory of the file
-    :type directory: str
+    :type directory: typing.Union[str, typing.Any]
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
+    :type hide_props_region: typing.Union[bool, typing.Any]
+    :param check_existing: Check Existing, Check and warn on overwriting existing files
+    :type check_existing: typing.Union[bool, typing.Any]
     :param filter_blender: Filter .blend files
-    :type filter_blender: bool
+    :type filter_blender: typing.Union[bool, typing.Any]
     :param filter_backup: Filter .blend files
-    :type filter_backup: bool
+    :type filter_backup: typing.Union[bool, typing.Any]
     :param filter_image: Filter image files
-    :type filter_image: bool
+    :type filter_image: typing.Union[bool, typing.Any]
     :param filter_movie: Filter movie files
-    :type filter_movie: bool
+    :type filter_movie: typing.Union[bool, typing.Any]
     :param filter_python: Filter python files
-    :type filter_python: bool
+    :type filter_python: typing.Union[bool, typing.Any]
     :param filter_font: Filter font files
-    :type filter_font: bool
+    :type filter_font: typing.Union[bool, typing.Any]
     :param filter_sound: Filter sound files
-    :type filter_sound: bool
+    :type filter_sound: typing.Union[bool, typing.Any]
     :param filter_text: Filter text files
-    :type filter_text: bool
+    :type filter_text: typing.Union[bool, typing.Any]
     :param filter_archive: Filter archive files
-    :type filter_archive: bool
+    :type filter_archive: typing.Union[bool, typing.Any]
     :param filter_btx: Filter btx files
-    :type filter_btx: bool
+    :type filter_btx: typing.Union[bool, typing.Any]
     :param filter_collada: Filter COLLADA files
-    :type filter_collada: bool
+    :type filter_collada: typing.Union[bool, typing.Any]
     :param filter_alembic: Filter Alembic files
-    :type filter_alembic: bool
+    :type filter_alembic: typing.Union[bool, typing.Any]
     :param filter_usd: Filter USD files
-    :type filter_usd: bool
+    :type filter_usd: typing.Union[bool, typing.Any]
     :param filter_obj: Filter OBJ files
-    :type filter_obj: bool
+    :type filter_obj: typing.Union[bool, typing.Any]
     :param filter_volume: Filter OpenVDB volume files
-    :type filter_volume: bool
+    :type filter_volume: typing.Union[bool, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_blenlib: Filter Blender IDs
-    :type filter_blenlib: bool
+    :type filter_blenlib: typing.Union[bool, typing.Any]
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
-    :type filemode: int
-    :param display_type: Display Type * DEFAULT Default -- Automatically determine display type for files. * LIST_VERTICAL Short List -- Display files as short list. * LIST_HORIZONTAL Long List -- Display files as a detailed list. * THUMBNAIL Thumbnails -- Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type filemode: typing.Optional[typing.Any]
+    :param display_type: Display Type * ``DEFAULT`` Default -- Automatically determine display type for files. * ``LIST_VERTICAL`` Short List -- Display files as short list. * ``LIST_HORIZONTAL`` Long List -- Display files as a detailed list. * ``THUMBNAIL`` Thumbnails -- Display files as thumbnails.
+    :type display_type: typing.Optional[typing.Any]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[str, int, typing.Any]
     '''
 
     pass
@@ -253,16 +256,16 @@ def asset_library_add(override_context: typing.
 def asset_library_remove(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None,
+                         undo: typing.Optional[bool] = None,
                          *,
-                         index: int = 0):
+                         index: typing.Optional[typing.Any] = 0):
     ''' Remove a path to a .blend file, so the Asset Browser will not attempt to show it anymore
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param index: Index
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -271,12 +274,12 @@ def asset_library_remove(override_context: typing.
 def associate_blend(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None):
+                    undo: typing.Optional[bool] = None):
     ''' Use this installation for .blend files and to display thumbnails
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -285,12 +288,12 @@ def associate_blend(override_context: typing.
 def autoexec_path_add(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None):
+                      undo: typing.Optional[bool] = None):
     ''' Add path to exclude from auto-execution
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -299,16 +302,16 @@ def autoexec_path_add(override_context: typing.
 def autoexec_path_remove(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None,
+                         undo: typing.Optional[bool] = None,
                          *,
-                         index: int = 0):
+                         index: typing.Optional[typing.Any] = 0):
     ''' Remove path to exclude from auto-execution
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param index: Index
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -317,12 +320,12 @@ def autoexec_path_remove(override_context: typing.
 def copy_prev(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
-    ''' Copy settings from previous version :file: startup/bl_operators/userpref.py\:128 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$128> _
+              undo: typing.Optional[bool] = None):
+    ''' Copy settings from previous version :file: `startup/bl_operators/userpref.py\:141 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$141>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -331,16 +334,16 @@ def copy_prev(override_context: typing.Union[typing.
 def keyconfig_activate(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: bool = None,
+                       undo: typing.Optional[bool] = None,
                        *,
-                       filepath: str = ""):
-    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+                       filepath: typing.Union[str, typing.Any] = ""):
+    ''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param filepath: filepath
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -349,28 +352,28 @@ def keyconfig_activate(override_context: typing.
 def keyconfig_export(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
+                     undo: typing.Optional[bool] = None,
                      *,
-                     all: bool = False,
-                     filepath: str = "",
-                     filter_folder: bool = True,
-                     filter_text: bool = True,
-                     filter_python: bool = True):
+                     all: typing.Union[bool, typing.Any] = False,
+                     filepath: typing.Union[str, typing.Any] = "",
+                     filter_folder: typing.Union[bool, typing.Any] = True,
+                     filter_text: typing.Union[bool, typing.Any] = True,
+                     filter_python: typing.Union[bool, typing.Any] = True):
     ''' Export key configuration to a python script
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all: All Keymaps, Write all keymaps (not just user modified)
-    :type all: bool
+    :type all: typing.Union[bool, typing.Any]
     :param filepath: filepath
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_text: Filter text
-    :type filter_text: bool
+    :type filter_text: typing.Union[bool, typing.Any]
     :param filter_python: Filter python
-    :type filter_python: bool
+    :type filter_python: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -379,28 +382,28 @@ def keyconfig_export(override_context: typing.
 def keyconfig_import(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
+                     undo: typing.Optional[bool] = None,
                      *,
-                     filepath: str = "keymap.py",
-                     filter_folder: bool = True,
-                     filter_text: bool = True,
-                     filter_python: bool = True,
-                     keep_original: bool = True):
+                     filepath: typing.Union[str, typing.Any] = "keymap.py",
+                     filter_folder: typing.Union[bool, typing.Any] = True,
+                     filter_text: typing.Union[bool, typing.Any] = True,
+                     filter_python: typing.Union[bool, typing.Any] = True,
+                     keep_original: typing.Union[bool, typing.Any] = True):
     ''' Import key configuration from a python script
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param filepath: filepath
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_text: Filter text
-    :type filter_text: bool
+    :type filter_text: typing.Union[bool, typing.Any]
     :param filter_python: Filter python
-    :type filter_python: bool
+    :type filter_python: typing.Union[bool, typing.Any]
     :param keep_original: Keep Original, Keep original file after copying to configuration folder
-    :type keep_original: bool
+    :type keep_original: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -409,12 +412,12 @@ def keyconfig_import(override_context: typing.
 def keyconfig_remove(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
-    ''' Remove key config :file: startup/bl_operators/userpref.py\:401 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$401> _
+                     undo: typing.Optional[bool] = None):
+    ''' Remove key config :file: `startup/bl_operators/userpref.py\:414 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$414>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -423,12 +426,12 @@ def keyconfig_remove(override_context: typing.
 def keyconfig_test(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
-    ''' Test key configuration for conflicts :file: startup/bl_operators/userpref.py\:150 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$150> _
+                   undo: typing.Optional[bool] = None):
+    ''' Test key configuration for conflicts :file: `startup/bl_operators/userpref.py\:163 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$163>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -437,12 +440,12 @@ def keyconfig_test(override_context: typing.
 def keyitem_add(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None):
-    ''' Add key map item :file: startup/bl_operators/userpref.py\:349 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$349> _
+                undo: typing.Optional[bool] = None):
+    ''' Add key map item :file: `startup/bl_operators/userpref.py\:362 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$362>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -451,16 +454,16 @@ def keyitem_add(override_context: typing.
 def keyitem_remove(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   item_id: int = 0):
+                   item_id: typing.Optional[typing.Any] = 0):
     ''' Remove key map item
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param item_id: Item Identifier, Identifier of the item to remove
-    :type item_id: int
+    :type item_id: typing.Optional[typing.Any]
     '''
 
     pass
@@ -469,16 +472,16 @@ def keyitem_remove(override_context: typing.
 def keyitem_restore(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    item_id: int = 0):
+                    item_id: typing.Optional[typing.Any] = 0):
     ''' Restore key map item
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param item_id: Item Identifier, Identifier of the item to restore
-    :type item_id: int
+    :type item_id: typing.Optional[typing.Any]
     '''
 
     pass
@@ -487,16 +490,16 @@ def keyitem_restore(override_context: typing.
 def keymap_restore(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   all: bool = False):
+                   all: typing.Union[bool, typing.Any] = False):
     ''' Restore key map(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param all: All Keymaps, Restore all keymaps to default
-    :type all: bool
+    :type all: typing.Union[bool, typing.Any]
     '''
 
     pass
@@ -505,12 +508,12 @@ def keymap_restore(override_context: typing.
 def reset_default_theme(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
-                        undo: bool = None):
+                        undo: typing.Optional[bool] = None):
     ''' Reset to the default theme colors
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -519,16 +522,16 @@ def reset_default_theme(override_context: typing.
 def studiolight_copy_settings(override_context: typing.
                               Union[typing.Dict, 'bpy.types.Context'] = None,
                               execution_context: typing.Union[str, int] = None,
-                              undo: bool = None,
+                              undo: typing.Optional[bool] = None,
                               *,
-                              index: int = 0):
+                              index: typing.Optional[typing.Any] = 0):
     ''' Copy Studio Light settings to the Studio Light editor
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param index: index
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -538,29 +541,29 @@ def studiolight_install(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
+        undo: typing.Optional[bool] = None,
         *,
-        files: bpy.types.
-        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
-        directory: str = "",
-        filter_folder: bool = True,
-        filter_glob: str = "*.png;*.jpg;*.hdr;*.exr",
-        type: typing.Union[str, int] = 'MATCAP'):
+        files: typing.Optional[bpy.types.bpy_prop_collection[
+            'bpy.types.OperatorFileListElement']] = None,
+        directory: typing.Union[str, typing.Any] = "",
+        filter_folder: typing.Union[bool, typing.Any] = True,
+        filter_glob: typing.Union[str, typing.Any] = "*.png;*.jpg;*.hdr;*.exr",
+        type: typing.Optional[typing.Any] = 'MATCAP'):
     ''' Install a user defined light
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param files: File Path
-    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
+    :type files: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']]
     :param directory: directory
-    :type directory: str
+    :type directory: typing.Union[str, typing.Any]
     :param filter_folder: Filter Folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_glob: filter_glob
-    :type filter_glob: str
-    :param type: Type * MATCAP MatCap -- Install custom MatCaps. * WORLD World -- Install custom HDRIs. * STUDIO Studio -- Install custom Studio Lights.
-    :type type: typing.Union[str, int]
+    :type filter_glob: typing.Union[str, typing.Any]
+    :param type: Type * ``MATCAP`` MatCap -- Install custom MatCaps. * ``WORLD`` World -- Install custom HDRIs. * ``STUDIO`` Studio -- Install custom Studio Lights.
+    :type type: typing.Optional[typing.Any]
     '''
 
     pass
@@ -569,16 +572,16 @@ def studiolight_install(
 def studiolight_new(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    filename: str = "StudioLight"):
+                    filename: typing.Union[str, typing.Any] = "StudioLight"):
     ''' Save custom studio light from the studio light editor settings
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param filename: Name
-    :type filename: str
+    :type filename: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -587,12 +590,12 @@ def studiolight_new(override_context: typing.
 def studiolight_show(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
-    ''' Show light preferences :file: startup/bl_operators/userpref.py\:1123 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$1123> _
+                     undo: typing.Optional[bool] = None):
+    ''' Show light preferences :file: `startup/bl_operators/userpref.py\:1136 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/userpref.py$1136>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -601,16 +604,16 @@ def studiolight_show(override_context: typing.
 def studiolight_uninstall(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: bool = None,
+                          undo: typing.Optional[bool] = None,
                           *,
-                          index: int = 0):
+                          index: typing.Optional[typing.Any] = 0):
     ''' Delete Studio Light
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param index: index
-    :type index: int
+    :type index: typing.Optional[typing.Any]
     '''
 
     pass
@@ -619,25 +622,25 @@ def studiolight_uninstall(override_context: typing.
 def theme_install(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None,
+                  undo: typing.Optional[bool] = None,
                   *,
-                  overwrite: bool = True,
-                  filepath: str = "",
-                  filter_folder: bool = True,
-                  filter_glob: str = "*.xml"):
+                  overwrite: typing.Union[bool, typing.Any] = True,
+                  filepath: typing.Union[str, typing.Any] = "",
+                  filter_folder: typing.Union[bool, typing.Any] = True,
+                  filter_glob: typing.Union[str, typing.Any] = "*.xml"):
     ''' Load and apply a Blender XML theme file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param overwrite: Overwrite, Remove existing theme file if exists
-    :type overwrite: bool
+    :type overwrite: typing.Union[bool, typing.Any]
     :param filepath: filepath
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     :param filter_folder: Filter folders
-    :type filter_folder: bool
+    :type filter_folder: typing.Union[bool, typing.Any]
     :param filter_glob: filter_glob
-    :type filter_glob: str
+    :type filter_glob: typing.Union[str, typing.Any]
     '''
 
     pass
