@@ -8,22 +8,22 @@ GenericType = typing.TypeVar("GenericType")
 def bake_to_keyframes(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None,
+                      undo: typing.Optional[bool] = None,
                       *,
-                      frame_start: int = 1,
-                      frame_end: int = 250,
-                      step: int = 1):
+                      frame_start: typing.Optional[typing.Any] = 1,
+                      frame_end: typing.Optional[typing.Any] = 250,
+                      step: typing.Optional[typing.Any] = 1):
     ''' Bake rigid body transformations of selected objects to keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param frame_start: Start Frame, Start frame for baking
-    :type frame_start: int
+    :type frame_start: typing.Optional[typing.Any]
     :param frame_end: End Frame, End frame for baking
-    :type frame_end: int
+    :type frame_end: typing.Optional[typing.Any]
     :param step: Frame Step, Frame Step
-    :type step: int
+    :type step: typing.Optional[typing.Any]
     '''
 
     pass
@@ -32,22 +32,23 @@ def bake_to_keyframes(override_context: typing.
 def connect(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
-            undo: bool = None,
+            undo: typing.Optional[bool] = None,
             *,
-            con_type: typing.Union[str, int] = 'FIXED',
-            pivot_type: typing.Union[str, int] = 'CENTER',
-            connection_pattern: typing.Union[str, int] = 'SELECTED_TO_ACTIVE'):
+            con_type: typing.Optional[typing.Any] = 'FIXED',
+            pivot_type: typing.Optional[typing.Any] = 'CENTER',
+            connection_pattern: typing.Optional[typing.
+                                                Any] = 'SELECTED_TO_ACTIVE'):
     ''' Create rigid body constraints between selected rigid bodies
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
-    :param con_type: Type, Type of generated constraint * FIXED Fixed -- Glue rigid bodies together. * POINT Point -- Constrain rigid bodies to move around common pivot point. * HINGE Hinge -- Restrict rigid body rotation to one axis. * SLIDER Slider -- Restrict rigid body translation to one axis. * PISTON Piston -- Restrict rigid body translation and rotation to one axis. * GENERIC Generic -- Restrict translation and rotation to specified axes. * GENERIC_SPRING Generic Spring -- Restrict translation and rotation to specified axes with springs. * MOTOR Motor -- Drive rigid body around or along an axis.
-    :type con_type: typing.Union[str, int]
-    :param pivot_type: Location, Constraint pivot location * CENTER Center -- Pivot location is between the constrained rigid bodies. * ACTIVE Active -- Pivot location is at the active object position. * SELECTED Selected -- Pivot location is at the selected object position.
-    :type pivot_type: typing.Union[str, int]
-    :param connection_pattern: Connection Pattern, Pattern used to connect objects * SELECTED_TO_ACTIVE Selected to Active -- Connect selected objects to the active object. * CHAIN_DISTANCE Chain by Distance -- Connect objects as a chain based on distance, starting at the active object.
-    :type connection_pattern: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param con_type: Type, Type of generated constraint * ``FIXED`` Fixed -- Glue rigid bodies together. * ``POINT`` Point -- Constrain rigid bodies to move around common pivot point. * ``HINGE`` Hinge -- Restrict rigid body rotation to one axis. * ``SLIDER`` Slider -- Restrict rigid body translation to one axis. * ``PISTON`` Piston -- Restrict rigid body translation and rotation to one axis. * ``GENERIC`` Generic -- Restrict translation and rotation to specified axes. * ``GENERIC_SPRING`` Generic Spring -- Restrict translation and rotation to specified axes with springs. * ``MOTOR`` Motor -- Drive rigid body around or along an axis.
+    :type con_type: typing.Optional[typing.Any]
+    :param pivot_type: Location, Constraint pivot location * ``CENTER`` Center -- Pivot location is between the constrained rigid bodies. * ``ACTIVE`` Active -- Pivot location is at the active object position. * ``SELECTED`` Selected -- Pivot location is at the selected object position.
+    :type pivot_type: typing.Optional[typing.Any]
+    :param connection_pattern: Connection Pattern, Pattern used to connect objects * ``SELECTED_TO_ACTIVE`` Selected to Active -- Connect selected objects to the active object. * ``CHAIN_DISTANCE`` Chain by Distance -- Connect objects as a chain based on distance, starting at the active object.
+    :type connection_pattern: typing.Optional[typing.Any]
     '''
 
     pass
@@ -56,16 +57,16 @@ def connect(override_context: typing.Union[typing.
 def constraint_add(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   type: typing.Union[int, str] = 'FIXED'):
+                   type: typing.Union[str, int] = 'FIXED'):
     ''' Add Rigid Body Constraint to active object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Rigid Body Constraint Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -74,12 +75,12 @@ def constraint_add(override_context: typing.
 def constraint_remove(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: bool = None):
+                      undo: typing.Optional[bool] = None):
     ''' Remove Rigid Body Constraint from Object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -88,19 +89,19 @@ def constraint_remove(override_context: typing.
 def mass_calculate(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None,
+                   undo: typing.Optional[bool] = None,
                    *,
-                   material: typing.Union[str, int] = 'DEFAULT',
-                   density: float = 1.0):
+                   material: typing.Union[str, int, typing.Any] = 'DEFAULT',
+                   density: typing.Optional[typing.Any] = 1.0):
     ''' Automatically calculate mass values for Rigid Body Objects based on volume
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param material: Material Preset, Type of material that objects are made of (determines material density)
-    :type material: typing.Union[str, int]
+    :type material: typing.Union[str, int, typing.Any]
     :param density: Density, Density value (kg/m^3), allows custom value if the 'Custom' preset is used
-    :type density: float
+    :type density: typing.Optional[typing.Any]
     '''
 
     pass
@@ -109,16 +110,16 @@ def mass_calculate(override_context: typing.
 def object_add(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: bool = None,
+               undo: typing.Optional[bool] = None,
                *,
-               type: typing.Union[int, str] = 'ACTIVE'):
+               type: typing.Union[str, int] = 'ACTIVE'):
     ''' Add active object as Rigid Body
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Rigid Body Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -127,12 +128,12 @@ def object_add(override_context: typing.
 def object_remove(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: bool = None):
+                  undo: typing.Optional[bool] = None):
     ''' Remove Rigid Body settings from Object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -141,12 +142,12 @@ def object_remove(override_context: typing.
 def object_settings_copy(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: bool = None):
-    ''' Copy Rigid Body settings from active object to selected :file: startup/bl_operators/rigidbody.py\:43 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/rigidbody.py$43> _
+                         undo: typing.Optional[bool] = None):
+    ''' Copy Rigid Body settings from active object to selected :file: `startup/bl_operators/rigidbody.py\:43 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/rigidbody.py$43>`_
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -155,16 +156,16 @@ def object_settings_copy(override_context: typing.
 def objects_add(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
+                undo: typing.Optional[bool] = None,
                 *,
-                type: typing.Union[int, str] = 'ACTIVE'):
+                type: typing.Union[str, int] = 'ACTIVE'):
     ''' Add selected objects as Rigid Bodies
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Rigid Body Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -173,12 +174,12 @@ def objects_add(override_context: typing.
 def objects_remove(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
+                   undo: typing.Optional[bool] = None):
     ''' Remove selected objects from Rigid Body simulation
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -187,16 +188,16 @@ def objects_remove(override_context: typing.
 def shape_change(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None,
+                 undo: typing.Optional[bool] = None,
                  *,
-                 type: typing.Union[int, str] = 'MESH'):
+                 type: typing.Union[str, int] = 'MESH'):
     ''' Change collision shapes for selected Rigid Body Objects
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param type: Rigid Body Shape
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -205,12 +206,12 @@ def shape_change(override_context: typing.
 def world_add(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Add Rigid Body simulation world to the current scene
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -219,12 +220,12 @@ def world_add(override_context: typing.Union[typing.
 def world_remove(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+                 undo: typing.Optional[bool] = None):
     ''' Remove Rigid Body simulation world from the current scene
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
