@@ -36,8 +36,9 @@ def cloth_filter(override_context: typing.
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
-                 type: typing.Optional[typing.Any] = 'GRAVITY',
+                 area_normal_radius: typing.Optional[typing.Any] = 0.25,
                  strength: typing.Optional[typing.Any] = 1.0,
+                 type: typing.Optional[typing.Any] = 'GRAVITY',
                  force_axis: typing.Optional[typing.Any] = {'X', 'Y', 'Z'},
                  orientation: typing.Optional[typing.Any] = 'LOCAL',
                  cloth_mass: typing.Optional[typing.Any] = 1.0,
@@ -49,10 +50,12 @@ def cloth_filter(override_context: typing.
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param type: Filter Type, Operation that is going to be applied to the mesh * ``GRAVITY`` Gravity -- Applies gravity to the simulation. * ``INFLATE`` Inflate -- Inflates the cloth. * ``EXPAND`` Expand -- Expands the cloth's dimensions. * ``PINCH`` Pinch -- Pulls the cloth to the cursor's start position. * ``SCALE`` Scale -- Scales the mesh as a soft body using the origin of the object as scale.
-    :type type: typing.Optional[typing.Any]
+    :param area_normal_radius: Normal Radius, Radius used for calculating area normal on initial click,in percentage of brush radius
+    :type area_normal_radius: typing.Optional[typing.Any]
     :param strength: Strength, Filter strength
     :type strength: typing.Optional[typing.Any]
+    :param type: Filter Type, Operation that is going to be applied to the mesh * ``GRAVITY`` Gravity -- Applies gravity to the simulation. * ``INFLATE`` Inflate -- Inflates the cloth. * ``EXPAND`` Expand -- Expands the cloth's dimensions. * ``PINCH`` Pinch -- Pulls the cloth to the cursor's start position. * ``SCALE`` Scale -- Scales the mesh as a soft body using the origin of the object as scale.
+    :type type: typing.Optional[typing.Any]
     :param force_axis: Force Axis, Apply the force in the selected axis * ``X`` X -- Apply force in the X axis. * ``Y`` Y -- Apply force in the Y axis. * ``Z`` Z -- Apply force in the Z axis.
     :type force_axis: typing.Optional[typing.Any]
     :param orientation: Orientation, Orientation of the axis to limit the filter force * ``LOCAL`` Local -- Use the local axis to limit the force and set the gravity direction. * ``WORLD`` World -- Use the global axis to limit the force and set the gravity direction. * ``VIEW`` View -- Use the view axis to limit the force and set the gravity direction.
@@ -75,18 +78,21 @@ def color_filter(override_context: typing.
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
-                 type: typing.Optional[typing.Any] = 'HUE',
+                 area_normal_radius: typing.Optional[typing.Any] = 0.25,
                  strength: typing.Optional[typing.Any] = 1.0,
+                 type: typing.Optional[typing.Any] = 'HUE',
                  fill_color: typing.Optional[typing.Any] = (0.0, 0.0, 0.0)):
     ''' Applies a filter to modify the active color attribute
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param type: Filter Type * ``FILL`` Fill -- Fill with a specific color. * ``HUE`` Hue -- Change hue. * ``SATURATION`` Saturation -- Change saturation. * ``VALUE`` Value -- Change value. * ``BRIGHTNESS`` Brightness -- Change brightness. * ``CONTRAST`` Contrast -- Change contrast. * ``SMOOTH`` Smooth -- Smooth colors. * ``RED`` Red -- Change red channel. * ``GREEN`` Green -- Change green channel. * ``BLUE`` Blue -- Change blue channel.
-    :type type: typing.Optional[typing.Any]
+    :param area_normal_radius: Normal Radius, Radius used for calculating area normal on initial click,in percentage of brush radius
+    :type area_normal_radius: typing.Optional[typing.Any]
     :param strength: Strength, Filter strength
     :type strength: typing.Optional[typing.Any]
+    :param type: Filter Type * ``FILL`` Fill -- Fill with a specific color. * ``HUE`` Hue -- Change hue. * ``SATURATION`` Saturation -- Change saturation. * ``VALUE`` Value -- Change value. * ``BRIGHTNESS`` Brightness -- Change brightness. * ``CONTRAST`` Contrast -- Change contrast. * ``SMOOTH`` Smooth -- Smooth colors. * ``RED`` Red -- Change red channel. * ``GREEN`` Green -- Change green channel. * ``BLUE`` Blue -- Change blue channel.
+    :type type: typing.Optional[typing.Any]
     :param fill_color: Fill Color
     :type fill_color: typing.Optional[typing.Any]
     '''
@@ -108,24 +114,6 @@ def detail_flood_fill(override_context: typing.
     pass
 
 
-def dirty_mask(override_context: typing.
-               Union[typing.Dict, 'bpy.types.Context'] = None,
-               execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
-               *,
-               dirty_only: typing.Union[bool, typing.Any] = False):
-    ''' Generates a mask based on the geometry cavity and pointiness
-
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param dirty_only: Dirty Only, Don't calculate cleans for convex areas
-    :type dirty_only: typing.Union[bool, typing.Any]
-    '''
-
-    pass
-
-
 def dynamic_topology_toggle(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
@@ -242,7 +230,7 @@ def face_set_change_visibility(
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param mode: Mode * ``TOGGLE`` Toggle Visibility -- Hide all Face Sets except for the active one. * ``SHOW_ACTIVE`` Show Active Face Set -- Show Active Face Set. * ``HIDE_ACTIVE`` Hide Active Face Sets -- Hide Active Face Sets. * ``INVERT`` Invert Face Set Visibility -- Invert Face Set Visibility. * ``SHOW_ALL`` Show All Face Sets -- Show All Face Sets.
+    :param mode: Mode * ``TOGGLE`` Toggle Visibility -- Hide all Face Sets except for the active one. * ``SHOW_ACTIVE`` Show Active Face Set -- Show Active Face Set. * ``HIDE_ACTIVE`` Hide Active Face Sets -- Hide Active Face Sets. * ``INVERT`` Invert Face Set Visibility -- Invert Face Set Visibility.
     :type mode: typing.Optional[typing.Any]
     '''
 
@@ -350,20 +338,6 @@ def face_sets_randomize_colors(
     pass
 
 
-def loop_to_vertex_colors(override_context: typing.
-                          Union[typing.Dict, 'bpy.types.Context'] = None,
-                          execution_context: typing.Union[str, int] = None,
-                          undo: typing.Optional[bool] = None):
-    ''' Copy the active loop color layer to the vertex color
-
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    '''
-
-    pass
-
-
 def mask_by_color(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
@@ -458,6 +432,42 @@ def mask_filter(override_context: typing.
     pass
 
 
+def mask_from_cavity(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: typing.Optional[bool] = None,
+                     *,
+                     mix_mode: typing.Optional[typing.Any] = 'MIX',
+                     mix_factor: typing.Optional[typing.Any] = 1.0,
+                     settings_source: typing.Optional[typing.Any] = 'OPERATOR',
+                     factor: typing.Optional[typing.Any] = 0.5,
+                     blur_steps: typing.Optional[typing.Any] = 2,
+                     use_curve: typing.Union[bool, typing.Any] = False,
+                     invert: typing.Union[bool, typing.Any] = False):
+    ''' Creates a mask based on the curvature of the surface
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    :param mix_mode: Mode, Mix mode
+    :type mix_mode: typing.Optional[typing.Any]
+    :param mix_factor: Mix Factor
+    :type mix_factor: typing.Optional[typing.Any]
+    :param settings_source: Settings, Use settings from here * ``OPERATOR`` Operator -- Use settings from operator properties. * ``BRUSH`` Brush -- Use settings from brush. * ``SCENE`` Scene -- Use settings from scene.
+    :type settings_source: typing.Optional[typing.Any]
+    :param factor: Factor, The contrast of the cavity mask
+    :type factor: typing.Optional[typing.Any]
+    :param blur_steps: Blur, The number of times the cavity mask is blurred
+    :type blur_steps: typing.Optional[typing.Any]
+    :param use_curve: Custom Curve
+    :type use_curve: typing.Union[bool, typing.Any]
+    :param invert: Cavity (Inverted)
+    :type invert: typing.Union[bool, typing.Any]
+    '''
+
+    pass
+
+
 def mask_init(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
@@ -482,8 +492,9 @@ def mesh_filter(
         execution_context: typing.Union[str, int] = None,
         undo: typing.Optional[bool] = None,
         *,
-        type: typing.Optional[typing.Any] = 'INFLATE',
+        area_normal_radius: typing.Optional[typing.Any] = 0.25,
         strength: typing.Optional[typing.Any] = 1.0,
+        type: typing.Optional[typing.Any] = 'INFLATE',
         deform_axis: typing.Optional[typing.Any] = {'X', 'Y', 'Z'},
         orientation: typing.Optional[typing.Any] = 'LOCAL',
         surface_smooth_shape_preservation: typing.Optional[typing.Any] = 0.5,
@@ -496,10 +507,12 @@ def mesh_filter(
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: typing.Optional[bool]
-    :param type: Filter Type, Operation that is going to be applied to the mesh * ``SMOOTH`` Smooth -- Smooth mesh. * ``SCALE`` Scale -- Scale mesh. * ``INFLATE`` Inflate -- Inflate mesh. * ``SPHERE`` Sphere -- Morph into sphere. * ``RANDOM`` Random -- Randomize vertex positions. * ``RELAX`` Relax -- Relax mesh. * ``RELAX_FACE_SETS`` Relax Face Sets -- Smooth the edges of all the Face Sets. * ``SURFACE_SMOOTH`` Surface Smooth -- Smooth the surface of the mesh, preserving the volume. * ``SHARPEN`` Sharpen -- Sharpen the cavities of the mesh. * ``ENHANCE_DETAILS`` Enhance Details -- Enhance the high frequency surface detail. * ``ERASE_DISCPLACEMENT`` Erase Displacement -- Deletes the displacement of the Multires Modifier.
-    :type type: typing.Optional[typing.Any]
+    :param area_normal_radius: Normal Radius, Radius used for calculating area normal on initial click,in percentage of brush radius
+    :type area_normal_radius: typing.Optional[typing.Any]
     :param strength: Strength, Filter strength
     :type strength: typing.Optional[typing.Any]
+    :param type: Filter Type, Operation that is going to be applied to the mesh * ``SMOOTH`` Smooth -- Smooth mesh. * ``SCALE`` Scale -- Scale mesh. * ``INFLATE`` Inflate -- Inflate mesh. * ``SPHERE`` Sphere -- Morph into sphere. * ``RANDOM`` Random -- Randomize vertex positions. * ``RELAX`` Relax -- Relax mesh. * ``RELAX_FACE_SETS`` Relax Face Sets -- Smooth the edges of all the Face Sets. * ``SURFACE_SMOOTH`` Surface Smooth -- Smooth the surface of the mesh, preserving the volume. * ``SHARPEN`` Sharpen -- Sharpen the cavities of the mesh. * ``ENHANCE_DETAILS`` Enhance Details -- Enhance the high frequency surface detail. * ``ERASE_DISCPLACEMENT`` Erase Displacement -- Deletes the displacement of the Multires Modifier.
+    :type type: typing.Optional[typing.Any]
     :param deform_axis: Deform Axis, Apply the deformation in the selected axis * ``X`` X -- Deform in the X axis. * ``Y`` Y -- Deform in the Y axis. * ``Z`` Z -- Deform in the Z axis.
     :type deform_axis: typing.Optional[typing.Any]
     :param orientation: Orientation, Orientation of the axis to limit the filter displacement * ``LOCAL`` Local -- Use the local axis to limit the displacement. * ``WORLD`` World -- Use the global axis to limit the displacement. * ``VIEW`` View -- Use the view axis to limit the displacement.
@@ -573,6 +586,20 @@ def project_line_gesture(
     pass
 
 
+def reveal_all(override_context: typing.
+               Union[typing.Dict, 'bpy.types.Context'] = None,
+               execution_context: typing.Union[str, int] = None,
+               undo: typing.Optional[bool] = None):
+    ''' Unhide all geometry
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: typing.Optional[bool]
+    '''
+
+    pass
+
+
 def sample_color(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
@@ -789,17 +816,3 @@ def uv_sculpt_stroke(override_context: typing.
     '''
 
     pass
-
-
-def vertex_to_loop_colors(override_context: typing.
-                          Union[typing.Dict, 'bpy.types.Context'] = None,
-                          execution_context: typing.Union[str, int] = None,
-                          undo: typing.Optional[bool] = None):
-    ''' Copy the Sculpt Vertex Color to a regular color layer
-
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    '''
-
-    pass
