@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def add(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: bool = None):
+        undo: typing.Optional[bool] = None):
     ''' Add a new workspace by duplicating the current one or appending one from the user configuration
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -22,19 +22,19 @@ def add(override_context: typing.Union[typing.
 def append_activate(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None,
+                    undo: typing.Optional[bool] = None,
                     *,
-                    idname: str = "",
-                    filepath: str = ""):
+                    idname: typing.Union[str, typing.Any] = "",
+                    filepath: typing.Union[str, typing.Any] = ""):
     ''' Append a workspace and make it the active one in the current window
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     :param idname: Identifier, Name of the workspace to append and activate
-    :type idname: str
+    :type idname: typing.Union[str, typing.Any]
     :param filepath: Filepath, Path to the library
-    :type filepath: str
+    :type filepath: typing.Union[str, typing.Any]
     '''
 
     pass
@@ -43,12 +43,12 @@ def append_activate(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: typing.Optional[bool] = None):
     ''' Delete the active workspace
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -57,12 +57,12 @@ def delete(override_context: typing.Union[typing.
 def duplicate(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: bool = None):
+              undo: typing.Optional[bool] = None):
     ''' Add a new workspace
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -71,12 +71,12 @@ def duplicate(override_context: typing.Union[typing.
 def reorder_to_back(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: bool = None):
+                    undo: typing.Optional[bool] = None):
     ''' Reorder workspace to be last in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -85,12 +85,12 @@ def reorder_to_back(override_context: typing.
 def reorder_to_front(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Reorder workspace to be first in the list
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
@@ -99,12 +99,12 @@ def reorder_to_front(override_context: typing.
 def scene_pin_toggle(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: bool = None):
+                     undo: typing.Optional[bool] = None):
     ''' Remember the last used scene for the current workspace and switch to it whenever this workspace is activated again
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: bool
+    :type undo: typing.Optional[bool]
     '''
 
     pass
