@@ -5,14 +5,15 @@ import bpy.types
 GenericType = typing.TypeVar("GenericType")
 
 
-def bake_action(obj: 'bpy.types.Object', *, action: 'bpy.types.Action',
-                frames: int, **kwargs) -> 'bpy.types.Action':
+def bake_action(obj: 'bpy.types.Object', *,
+                action: typing.Optional['bpy.types.Action'], frames: int,
+                **kwargs) -> 'bpy.types.Action':
     ''' 
 
     :param obj: Object to bake.
     :type obj: 'bpy.types.Object'
     :param action: An action to bake the data into, or None for a new action to be created.
-    :type action: 'bpy.types.Action'
+    :type action: typing.Optional['bpy.types.Action']
     :param frames: Frames to bake.
     :type frames: int
     :rtype: 'bpy.types.Action'
@@ -24,7 +25,7 @@ def bake_action(obj: 'bpy.types.Object', *, action: 'bpy.types.Action',
 
 def bake_action_iter(obj: 'bpy.types.Object',
                      *,
-                     action: 'bpy.types.Action',
+                     action: typing.Optional['bpy.types.Action'],
                      only_selected: bool = False,
                      do_pose: bool = True,
                      do_object: bool = True,
@@ -37,7 +38,7 @@ def bake_action_iter(obj: 'bpy.types.Object',
     :param obj: Object to bake.
     :type obj: 'bpy.types.Object'
     :param action: An action to bake the data into, or None for a new action to be created.
-    :type action: 'bpy.types.Action'
+    :type action: typing.Optional['bpy.types.Action']
     :param only_selected: Only bake selected bones.
     :type only_selected: bool
     :param do_pose: Bake pose channels.
@@ -60,24 +61,26 @@ def bake_action_iter(obj: 'bpy.types.Object',
 
 
 def bake_action_objects(object_action_pairs, *, frames: int,
-                        **kwargs) -> 'bpy.types.Action':
-    ''' A version of :func: bake_action_objects_iter that takes frames and returns the output.
+                        **kwargs) -> typing.Sequence['bpy.types.Action']:
+    ''' A version of :func:`bake_action_objects_iter` that takes frames and returns the output.
 
     :param frames: Frames to bake.
     :type frames: int
-    :rtype: 'bpy.types.Action'
-    :return: A sequence of Action or None types (aligned with object_action_pairs )
+    :rtype: typing.Sequence['bpy.types.Action']
+    :return: A sequence of Action or None types (aligned with `object_action_pairs`)
     '''
 
     pass
 
 
-def bake_action_objects_iter(object_action_pairs: 'bpy.types.Sequence',
-                             **kwargs):
+def bake_action_objects_iter(
+        object_action_pairs: typing.
+        Union['bpy.types.Sequence', 'bpy.types.Object', 'bpy.types.Action'],
+        **kwargs):
     ''' An coroutine that bakes actions for multiple objects.
 
     :param object_action_pairs: Sequence of object action tuples, action is the destination for the baked data. When None a new action will be created.
-    :type object_action_pairs: 'bpy.types.Sequence'
+    :type object_action_pairs: typing.Union['bpy.types.Sequence', 'bpy.types.Object', 'bpy.types.Action']
     '''
 
     pass
