@@ -10,7 +10,7 @@ def location_3d_to_region_2d(region: 'bpy.types.Region',
                              rv3d: 'bpy.types.RegionView3D',
                              coord: 'mathutils.Vector',
                              *,
-                             default=None) -> 'mathutils.Vector':
+                             default: typing.Any = None) -> 'mathutils.Vector':
     ''' Return the *region* relative 2d location of a 3d position.
 
     :param region: region of the 3D viewport, typically bpy.context.region.
@@ -19,7 +19,8 @@ def location_3d_to_region_2d(region: 'bpy.types.Region',
     :type rv3d: 'bpy.types.RegionView3D'
     :param coord: 3d worldspace location.
     :type coord: 'mathutils.Vector'
-    :param default:  Return this value if coord is behind the origin of a perspective view.
+    :param default:  Return this value if ``coord`` is behind the origin of a perspective view.
+    :type default: typing.Any
     :rtype: 'mathutils.Vector'
     :return: 2d location
     '''
@@ -48,11 +49,12 @@ def region_2d_to_location_3d(
     pass
 
 
-def region_2d_to_origin_3d(region: 'bpy.types.Region',
-                           rv3d: 'bpy.types.RegionView3D',
-                           coord: 'mathutils.Vector',
-                           *,
-                           clamp: float = None) -> 'mathutils.Vector':
+def region_2d_to_origin_3d(
+        region: 'bpy.types.Region',
+        rv3d: 'bpy.types.RegionView3D',
+        coord: 'mathutils.Vector',
+        *,
+        clamp: typing.Optional[float] = None) -> 'mathutils.Vector':
     ''' Return the 3d view origin from the region relative 2d coords.
 
     :param region: region of the 3D viewport, typically bpy.context.region.
@@ -62,7 +64,7 @@ def region_2d_to_origin_3d(region: 'bpy.types.Region',
     :param coord: 2d coordinates relative to the region; (event.mouse_region_x, event.mouse_region_y) for example.
     :type coord: 'mathutils.Vector'
     :param clamp: Clamp the maximum far-clip value used. (negative value will move the offset away from the view_location)
-    :type clamp: float
+    :type clamp: typing.Optional[float]
     :rtype: 'mathutils.Vector'
     :return: The origin of the viewpoint in 3d space.
     '''
