@@ -277,7 +277,7 @@ class Context:
         '''
         pass
 
-    def path_resolve(self):
+    def path_resolve(self, path, coerce):
         ''' 
 
         '''
@@ -301,6 +301,12 @@ class Context:
         '''
         pass
 
+    def temp_override(self):
+        ''' 
+
+        '''
+        pass
+
     def type_recast(self):
         ''' 
 
@@ -2368,9 +2374,6 @@ class _GenericBone:
     center = None
     ''' '''
 
-    children = None
-    ''' '''
-
     children_recursive = None
     ''' '''
 
@@ -2616,9 +2619,6 @@ class Bone(_GenericBone):
     center = None
     ''' '''
 
-    children = None
-    ''' '''
-
     children_recursive = None
     ''' '''
 
@@ -4105,6 +4105,170 @@ class CompositorNode(NodeInternal, Node):
         pass
 
 
+class GeometryNode(NodeInternal, Node):
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_clear(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ensure(self):
+        ''' 
+
+        '''
+        pass
+
+    def id_properties_ui(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_registered_node_type(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, ntree):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
 class ShaderNode(NodeInternal, Node):
     bl_rna = None
     ''' '''
