@@ -68,23 +68,7 @@ def rna_idprop_ui_create(item, prop, default, min, max, soft_min, soft_max,
     pass
 
 
-def rna_idprop_ui_del(item):
-    ''' 
-
-    '''
-
-    pass
-
-
-def rna_idprop_ui_get(item, create):
-    ''' 
-
-    '''
-
-    pass
-
-
-def rna_idprop_ui_prop_clear(item, prop, remove):
+def rna_idprop_ui_prop_clear(item, prop):
     ''' 
 
     '''
@@ -100,14 +84,6 @@ def rna_idprop_ui_prop_default_set(item, prop, value):
     pass
 
 
-def rna_idprop_ui_prop_get(item, prop, create):
-    ''' 
-
-    '''
-
-    pass
-
-
 def rna_idprop_ui_prop_update(item, prop):
     ''' 
 
